@@ -2,6 +2,7 @@
 
 #include "osl/search/alphaBeta2.h"
 #include "osl/search/alphaBeta3.h"
+#include "osl/search/alphaBeta4.h"
 #include "osl/search/searchRecorder.h"
 #include "osl/search/simpleHashTable.h"
 #include "osl/search/simpleHashRecord.h"
@@ -113,9 +114,10 @@ int main(int argc, char **argv)
     OslConfig::setEvalRandom(eval_options.eval_random);
 #endif
   const bool use_alphabeta3 = (eval_options.eval_type == "test3");
+  const bool use_alphabeta4 = (eval_options.eval_type == "test4");
   const bool use_test_eval = (eval_options.eval_type == "test");
 
-  if (use_test_eval || use_alphabeta3)
+  if (use_test_eval || use_alphabeta3 || use_alphabeta4)
   {
     const bool load_success 
       = eval_options.eval_filename.empty() 
@@ -172,6 +174,8 @@ int main(int argc, char **argv)
 #ifndef MINIMAL
     if (use_alphabeta3)
       processFile<AlphaBeta3>(filename);
+    if (use_alphabeta4)
+      processFile<AlphaBeta4>(filename);
     else if (use_test_eval)
 #endif
       processFile<AlphaBeta2OpenMidEndingEval>(filename);
@@ -309,9 +313,6 @@ void processFile(const char *filename)
   double consumed = started.elapsedSeconds();
 
   std::cerr << best_move << "\n";
-
-  if (verbose > 1)
-    searcher.showNodeDepth(std::cerr);
   
   if (go_forward < moves.size())
   {
