@@ -70,6 +70,12 @@ SearchPlayer *makePlayer(const std::string& eval_type, bool use_alpha_beta)
 {
     if (OslConfig::verbose())
       std::cerr << "using alpha beta\n";
+#ifndef MINIMAL
+    if (eval_type == "test3")
+      return new AlphaBeta3OpenMidEndingEvalPlayer();
+    if (eval_type == "test4")
+      return new AlphaBeta4Player();
+#endif
 #ifndef MINIMAL
     if (eval_type == "test")
 #endif
@@ -144,6 +150,7 @@ void play(int argc,char **argv)
   if (vm.count("version")) {
     std::cout << "gpsshogi " << gpsshogi::gpsshogi_revision << "\n\n"
       << "Copyright (C) 2003-2011 Team GPS.\n";
+    std::cout << "osl " << OslConfig::configuration() << '\n';
     return;
   }
 
@@ -185,6 +192,8 @@ void play(int argc,char **argv)
   const bool load_success 
 #ifndef MINIMAL
     = (eval_options.eval_type == "test"
+       || eval_options.eval_type == "test3"
+       || eval_options.eval_type == "test4"
 #else
     = ( true
 #endif
@@ -204,7 +213,9 @@ void play(int argc,char **argv)
     throw std::runtime_error("evaluation function setup failure");
   }
 #ifndef MINIMAL
-  if (eval_options.eval_type == "test")
+  if (eval_options.eval_type == "test"
+      || eval_options.eval_type == "test3"
+      || eval_options.eval_type == "test4")
 #endif
   {
     const bool load_success 
