@@ -42,6 +42,8 @@
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/asio.hpp>
+#include <boost/iostreams/concepts.hpp>
+#include <boost/iostreams/stream.hpp>
 namespace po = boost::program_options;
 #include <string>
 #include <sstream>
@@ -50,14 +52,42 @@ namespace po = boost::program_options;
 #  include <malloc.h>
 #endif
 #include <unistd.h>
+
 #ifndef NDEBUG
 const bool debug=true;
 #else
 const bool debug=false;
 #endif
+
+// rewrite asio::tcp::iostream, as it stop support for parallel read/write
+// at somepoint betweer 1.42-1.48.
+class tcp_istream : public boost::iostreams::source
+{
+  boost::asio::ip::tcp::socket& socket;
+public:
+  tcp_istream(boost::asio::ip::tcp::socket& s) : socket(s) {
+  }
+  std::streamsize read(char* s, std::streamsize n) {
+    n = boost::asio::read(socket, boost::asio::buffer(s, 1));
+    return n;
+  }
+};
+class tcp_ostream : public boost::iostreams::sink
+{
+  boost::asio::ip::tcp::socket& socket;
+public:
+  tcp_ostream(boost::asio::ip::tcp::socket& s) : socket(s) {
+  }
+  std::streamsize write(const char* s, std::streamsize n) {
+    return boost::asio::write(socket, boost::asio::buffer(s, n));
+  }
+};
+  
+// ---
+
+
 bool read_from_file = false;
 volatile bool suspend_reading = false;
-
 using namespace osl;
 CArray<int,2> bwtime;
 MoveVector ignore_moves;
@@ -819,7 +849,9 @@ void play(std::istream& is, std::ostream& os)
 #endif
   if (hostname != "")
     name += hostname + " ";
-  os << name << gpsshogi::gpsshogi_revision << "\n";
+  os << name << gpsshogi::gpsshogi_revision
+     << " " << OslConfig::configuration()
+     << "\n";
   os << "id author teamgps\n";
   os << "option name LimitDepth type spin default " << limit_depth << " min 4 max 10\n";
   os << "option name BookDepth type spin default " << book_depth << " min 0 max 100\n";
@@ -879,7 +911,7 @@ void play(std::istream& is, std::ostream& os)
 	initalized = true;
       }
       const char *msg = "readyok";
-      os << msg << "\n";
+      os << msg << "\n" << std::flush;
       if (debug)
 	std::cerr << msg << "\n";
       send_udp_log(msg);
@@ -1214,6 +1246,7 @@ int main(int argc, char **argv)
   if (vm.count("version")) {
     std::cout << "gpsusi " << gpsshogi::gpsshogi_revision << "\n\n"
       << "Copyright (C) 2003-2011 Team GPS.\n";
+    std::cout << "osl " << OslConfig::configuration() << '\n';
     return 0;
   }
   char name[128] = {0};
@@ -1280,17 +1313,21 @@ int main(int argc, char **argv)
     boost::algorithm::split(args, io_stream, boost::algorithm::is_any_of(":"));
     assert(args.size() == 3);
     while (1) {
-      std::cerr << "connecting " << std::flush;
       using boost::asio::ip::tcp;
-      boost::scoped_ptr<tcp::iostream> s
-	(new tcp::iostream(args[1], args[2]));
-      while (! *s) {
+      tcp::resolver resolver(io_service);
+      tcp::resolver::query query(tcp::v4(), args[1], args[2]);
+      tcp::endpoint server(*resolver.resolve(query));
+      tcp::socket socket(io_service);
+      std::cerr << "connecting " << server << std::flush;
+      boost::system::error_code ec;      
+      while (socket.connect(server, ec)) {
 	std::cerr << "." << std::flush;
 	boost::this_thread::sleep(boost::posix_time::seconds(15));
-	s.reset(new tcp::iostream(args[1], args[2]));
       }
       std::cerr << "\n" << std::flush;
-      play(*s, *s);
+      boost::iostreams::stream<tcp_istream> is(socket);
+      boost::iostreams::stream<tcp_ostream> os(socket);
+      play(is, os);
       // fall back to reconnect in case of server down
       boost::this_thread::sleep(boost::posix_time::seconds(15));
     }
