@@ -13,6 +13,7 @@ my $sente = $options{s} || 0;
 my $command = $options{c};
 my $dir = $options{d} || ".";
 my ($reader, $writer);
+my $my_color = $sente ? '+' : '-';
 my $pid = open2($reader, $writer, $command);
 
 my $session_in = new CsaFileSession($dir."/in", 0);
@@ -36,6 +37,12 @@ while ($line = $session_in->read()) {
   chomp $line;
   print STDERR "TGPS:$line\n";
   print $writer $line."\n";
+  if ($line =~ /^$my_color/) {	# the last line was echoback of my move
+    $line = $session_in->read();
+    chomp $line;
+    print STDERR "TGPS:$line\n";
+    print $writer $line."\n";
+  }
   $line = <$reader>;
   chomp $line;
   print STDERR "FGPS:$line\n";
