@@ -21,6 +21,7 @@ namespace gpsshogi
       void setState(const osl::state::SimpleState &state);
       void moveReserve(osl::Player, osl::Ptype, osl::Square);
       void reserveToStand(osl::Player);
+      void setTurn(osl::Player);
     public slots:
       void clearState();
     protected:
@@ -38,6 +39,7 @@ namespace gpsshogi
       osl::misc::CArray<osl::Piece, osl::Square::SIZE> board;
       osl::misc::CArray<osl::Piece, osl::Piece::SIZE> pieces;
       int modifiers;
+      osl::Player turn;
     };
   }
 }
