@@ -380,6 +380,22 @@ AbstractBoard::positionToPoint(osl::Square position) const
 		BOX_SIZE * (y - 1) + MARGIN_HEAD);
 }
 
+const QPoint gpsshogi::gui::
+AbstractBoard::standToPoint(osl::Player player, osl::Ptype ptype) const
+{
+  int i = std::find(osl::PieceStand::order.begin(),
+		    osl::PieceStand::order.end(), ptype)
+    - osl::PieceStand::order.begin();
+  if ((player == osl::BLACK) ^ reversed()) {
+    int y = BOX_SIZE + i * BOX_SIZE;
+    return QPoint(BLACK_STAND_X, y);
+  }
+  else {
+    int y = BOX_SIZE*2 + (osl::PieceStand::order.size()-i) * BOX_SIZE;
+    return QPoint(BOX_SIZE, y);
+  }
+}
+
 void gpsshogi::gui::
 AbstractBoard::mouseMoveEvent(QMouseEvent *e)
 {
@@ -389,3 +405,7 @@ AbstractBoard::mouseMoveEvent(QMouseEvent *e)
     update();
   }
 }
+// ;;; Local Variables:
+// ;;; mode:c++
+// ;;; c-basic-offset:2
+// ;;; End:
