@@ -154,8 +154,9 @@ function DisplayTable(display_id, csa_id, move_length, board) {
 	  exp3.setAttribute("class", "hidden");
 	  close.setAttribute("class", "clickable");
 	  csa_body.innerHTML = "<pre>"
+	+"ꡧ"+state.getPlayer(false)+"\r\n"
 	+state.toKi2CsaStyle()
-	.replace(/P\+/g, "λ:").replace(/P-/g, "λ:")
+	.replace(/P\+/g, "λ").replace(/P-/g, "λ")
 	.replace(/\* /g, "").replace(/\+/g, " ").replace(/-/g, "v")
 	.replace(/FU/g, "").replace(/KY/g, "").replace(/KE/g, "")
 	.replace(/GI/g, "").replace(/KI/g, "").replace(/KA/g, "")
@@ -174,6 +175,10 @@ function DisplayTable(display_id, csa_id, move_length, board) {
 	   function (all,s1,s2) { return "|"+s2+"|"+kanjiNumber[s1]+"\n"; })
 	.replace(/([0-9])/g, function (all,s1) { return kanjiNumber[s1]; })
 	.replace(/\n/g, "\r\n")
+	+"ꡧ"+state.getPlayer(true)+"\r\n"
+	+"*" + state.getEvent() + "\r\n"
+	+"=" + state.getMoveIndex() + "\r\n"
+	+(state.getTurn() ? "" : "\r\n")
 	+"</pre>";
       };
       exp3.onclick = function() {
@@ -438,6 +443,7 @@ BoardManager.prototype.update = function(update_display) {
   var comments = board.getComments();
   var move_comments = board.getMoveComments();
 
+  board.setMoveIndex(this.index);
   if (this.index == 0)
     return;
 
