@@ -366,6 +366,10 @@ int main(int argc, char **argv)
 	moves = kisen.getMoves(cur_record);
 	cur_position = 0;
 	state = NumEffectState(kisen.getInitialState());
+	if (record < 0)
+	{
+	  continue;
+	}
 	if (++num_processed >= num_records && num_records > 0)
 	  break;
       }
