@@ -36,7 +36,7 @@ static void validate(double search_window_for_validation,
     {
       search_window_for_validation, sigmoid_alpha,
       max_progress, cross_validation_randomness,
-      min_rating, eval
+      (size_t)min_rating, eval
     };
   boost::ptr_vector<boost::thread> threads;
       
