@@ -141,8 +141,7 @@ int main(int argc, char **argv)
 	} 
       }
       gpsshogi::PVVector pv;
-      vector<std::pair<int, double> > diffs;
-      diffs.reserve(my_eval->maxActive() * 2);
+      gpsshogi::MoveData data;
       hash_set<int> found_features;
       while (pr.readPv(pv))
       {
@@ -151,8 +150,9 @@ int main(int argc, char **argv)
 	{
 	  current_state.makeMove(pv[j]);
 	}
-	double value;
-	my_eval->features(current_state, value, diffs);
+	const int& value = data.value;
+	const vector<std::pair<int, double> >& diffs = data.diffs;
+	my_eval->features(current_state, data);
 	for (size_t j = 0; j < diffs.size(); ++j)
 	{
 	  if (watch_indices.find(diffs[j].first) !=
@@ -163,8 +163,7 @@ int main(int argc, char **argv)
 	  }
 	}
 	const Move first_move = pv[0];
-	pv.clear();
-	diffs.clear();
+	data.clear();
 	for (hash_set<int>::const_iterator it = found_features.begin();
 	     it != found_features.end();
 	     ++it)
@@ -180,8 +179,7 @@ int main(int argc, char **argv)
 	  {
 	    current_state.makeMove(pv[j]);
 	  }
-	  double dummy2;
-	  my_eval->features(current_state, dummy2, diffs);
+	  my_eval->features(current_state, data);
 	  for (size_t j = 0; j < diffs.size(); ++j)
 	  {
 	    if (watch_indices.find(diffs[j].first) !=
@@ -195,8 +193,7 @@ int main(int argc, char **argv)
 	  // Restore state
 	  weights[*it] = original_value;
 	  my_eval->setWeight(&weights[0]);
-	  pv.clear();
-	  diffs.clear();
+	  data.clear();
 	}
 	found_features.clear();
       }
