@@ -16,6 +16,7 @@
 #include "osl/misc/milliSeconds.h"
 #include "osl/misc/ncores.h"
 #include "osl/misc/binaryIO.h"
+#include "osl/stat/histogram.h"
 
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <boost/scoped_ptr.hpp>
@@ -65,6 +66,9 @@ bool rotate_record_mode;
 
 boost::scoped_ptr<RotateRecord> rotate_record;
 
+/** 進行度が後半まで分布するよう重みを加える */
+double force_progress;
+
 int main(int argc, char **argv)
 {
   nice(20);
@@ -200,6 +204,9 @@ int main(int argc, char **argv)
     ("priority-record-text",
      po::value<std::string>(&priority_record_text)->default_value(""),
      "specify a filename contaiting record ids that will be given priority when --record-coverage x < 100.")
+    ("force-progress",
+     po::value<double>(&force_progress)->default_value(0.0),
+     "experimental feature only for effectprogress")
     ("help", "produce help message")
     ;
 
@@ -282,6 +289,9 @@ static int position_randomness = 1;
 
 valarray_t gradient[MaxThreads], Hv[MaxThreads], v_for_Hv;
 stat::Average errors[MaxThreads];
+boost::scoped_ptr<Histogram> progress_count[MaxThreads];
+boost::scoped_ptr<Histogram> progress_count_prev;
+vector<int> progress_count_sum;
 /** feature の出現率 */
 valarray_t frequency[MaxThreads];
 /** feature の出現回数 */
@@ -293,6 +303,29 @@ long long total[MaxThreads];
 /** 監視対象の重み */
 vector<int> watch_list;
 
+void init_progress_count()
+{
+  for (size_t i=0; i<num_cpus; ++i)
+    progress_count[i].reset(new Histogram(1, my_eval->maxProgress()));
+}
+void merge_progress_count()
+{
+  progress_count_prev.reset(new Histogram(1, my_eval->maxProgress()));
+  for (size_t i=0; i<num_cpus; ++i)
+    progress_count_prev->merge(*progress_count[i]);
+  progress_count_sum.resize(my_eval->maxProgress());
+  for (int i=0; i<my_eval->maxProgress(); ++i) {
+    progress_count_sum[i] = progress_count_prev->frequency(i);
+    if (i>0)
+      progress_count_sum[i] += progress_count_sum[i-1];
+  }
+}
+void write_progress_count(const std::string& text_name)
+{
+  std::ofstream os(text_name.c_str());
+  progress_count_prev->show(os);
+}
+
 struct ProcessPVBase
 {
   int thread_id, min_count;
@@ -303,8 +336,11 @@ struct ProcessPVBase
   virtual ~ProcessPVBase() {}
   void operator()() const;
   virtual void beginPosition(double turn_coef, MoveData& selected) const {}
+  virtual void beginPositionProgress(double turn_coef, MoveData& selected) const {}
   virtual void processInstance(double turn_coef, MoveData& selected, MoveData& sibling,
 			       double weight, double progress) const=0;
+  virtual void processInstanceProgress(double turn_coef, MoveData& selected, MoveData& sibling,
+				       double weight, double progress) const {}
   virtual void endPosition() const {}
   virtual void finishRecord() const {}
 };
@@ -353,14 +389,30 @@ void ProcessPVBase::operator()() const
     assert(has_best_move);
     if (!has_best_move)
       return;
-    MoveData selected, sibling;
-    Analyzer::analyzeLeaf(state, pv, *my_eval, selected);
+    MoveData selected, sibling, progress_selected, progress_sibling;
+    // analyze_leaf
+    {
+      NumEffectState leaf_state(state);
+      Analyzer::makeLeaf(leaf_state, pv);
+      my_eval->features(leaf_state, selected);
+      if (force_progress)
+	my_eval->featuresProgress(leaf_state, progress_selected);	
+    }
     const int turn_coef = (state.turn() == BLACK) ? 1 : -1;
     beginPosition(turn_coef, selected);
+    if (force_progress)
+      beginPositionProgress(turn_coef, progress_selected);
     int num_sibling = 0;
     while (pr.readPv(pv)) {
       ++num_pv; ++num_sibling;
-      Analyzer::analyzeLeaf(state, pv, *my_eval, sibling);
+      // analyze_leaf
+      {
+	NumEffectState leaf_state(state);
+	Analyzer::makeLeaf(leaf_state, pv);
+	my_eval->features(leaf_state, sibling);
+	if (force_progress)
+	  my_eval->featuresProgress(leaf_state, progress_sibling);	
+      }
       double progress = 1.0*cur_position/moves.size(); // [0,1]
       double weight = weight_midgame ? (1.0 - abs(0.5-progress)) : 1.0;
       if (weight_winner && moves.size() < 256 
@@ -371,6 +423,9 @@ void ProcessPVBase::operator()() const
         weight *= 5;
       }
       processInstance(turn_coef, selected, sibling, weight, progress);
+      if (force_progress)
+	processInstanceProgress(turn_coef, progress_selected,
+				progress_sibling, weight, progress);
     }
     endPosition();
   }
@@ -386,6 +441,7 @@ struct ProcessPVCount : public ProcessPVBase
   }
   void beginPosition(double /*turn_coef*/, MoveData& selected) const
   {
+    progress_count[thread_id]->add(selected.progress);
 #ifdef L1BALL_NO_SORT
     std::sort(selected.diffs.begin(), selected.diffs.end());
 #endif
@@ -396,6 +452,7 @@ struct ProcessPVCount : public ProcessPVBase
 
 void ProcessPVCount::processInstance(double turn_coef, MoveData& selected, MoveData& sibling, double, double) const
 {
+  progress_count[thread_id]->add(sibling.progress);
   assert(__gnu_cxx::is_sorted(selected.diffs.begin(), selected.diffs.end()));
   std::sort(sibling.diffs.begin(), sibling.diffs.end());
   instance.clear();
@@ -442,7 +499,10 @@ struct ProcessPV : public ProcessPVBase
   {
   }
   void beginPosition(double turn_coef, MoveData& selected) const;
+  void beginPositionProgress(double turn_coef, MoveData& selected) const;
   void processInstance(double, MoveData&, MoveData&, double, double) const;
+  void processInstanceProgress(double turn_coef, MoveData& selected, MoveData& sibling,
+			       double weight, double progress) const;
   void endPosition() const;
 };
 
@@ -456,6 +516,20 @@ void ProcessPV::beginPosition(double turn_coef, MoveData& selected) const {
 #endif
 }
 
+void ProcessPV::beginPositionProgress(double turn_coef, MoveData& selected) const { 
+  if (force_progress) {
+    // progress_count[thread_id]->add(selected.progress);
+    sparse_vector_t empty_a;
+    double agsum_dummy;
+    double progress = ValarrayUtil::dot(selected.diffs, w, count, min_count);
+    double error = std::max(0.0, my_eval->maxProgress()/scaling_factor-progress);
+    HingeLoss::addGradientSep(w, error, empty_a,
+			      selected.diffs, -1, count, min_count,
+			      gradient[thread_id], agsum_dummy, force_progress);
+    errors[thread_id].add(error*force_progress);
+  }
+}
+
 void ProcessPV::endPosition() const
 {
 #ifdef L1BALL_NO_SORT
@@ -535,6 +609,21 @@ void ProcessPV::processInstance(double turn_coef, MoveData& selected, MoveData&
   errors[thread_id].add(loss);
 }
 
+void ProcessPV::processInstanceProgress(double turn_coef, MoveData& selected, MoveData& sibling, double instance_weight, double progress) const
+{
+  if (force_progress) {
+    // progress_count[thread_id]->add(sibling.progress);
+    sparse_vector_t empty_a;
+    double agsum_dummy;
+    double progress = ValarrayUtil::dot(sibling.diffs, w, count, min_count);
+    double error = std::max(0.0, my_eval->maxProgress()/scaling_factor-progress);
+    HingeLoss::addGradientSep(w, error, empty_a,
+			      sibling.diffs, -1, count, min_count,
+			      gradient[thread_id], agsum_dummy, force_progress);
+    errors[thread_id].add(error*force_progress);
+  }
+}
+
 /* ------------------------------------------------------------------------- */
 class GradientDescentUtil
 {
@@ -666,9 +755,11 @@ void count_all()
     count_by_record[i].resize(my_eval->dimension());
     count_by_record[i] = 0.0;
   }
+  init_progress_count();
   boost::ptr_vector<boost::thread> threads;
-  for (size_t i=0; i<num_cpus; ++i)
+  for (size_t i=0; i<num_cpus; ++i) {
     threads.push_back(new boost::thread(ProcessPVCount(i)));
+  }
   for (size_t i=0; i<num_cpus; ++i) {
     threads[i].join();
     if (i == 0)
@@ -677,6 +768,7 @@ void count_all()
     total[0] += total[i];
     count_by_record[0] += count_by_record[i];
   }
+  merge_progress_count();
   count.resize(frequency[0].size());
   copy(&frequency[0][0], &frequency[0][0]+frequency[0].size(), count.begin());
   frequency[0] /= total[0];
@@ -709,6 +801,7 @@ void count_all()
 static double eta = 1e-9;
 void learn(valarray_t& w)
 {
+  valarray_t old_w = w;
   boost::scoped_ptr<L1BallBase> solver;
   if (smd)
     solver.reset(new GradientDescentSMD);
@@ -719,7 +812,7 @@ void learn(valarray_t& w)
     solver.reset(l);
   }
   solver->setMeanAbsWeight(lambda);
-  solver->setTolerance(1e-4);
+  solver->setTolerance(1e-8);
   solver->setEta0(eta);
   solver->setEtaIncrement(eta_increment);
   solver->setMaxIteration(num_iteration_internal);
@@ -727,6 +820,8 @@ void learn(valarray_t& w)
   eta = L1Ball::l1norm(solver->lastEta())/solver->lastEta().size()/2.0;
   std::cerr << " finished " << solver->lastError() << " " << eta
 	    << "(" << solver->lastEta().max() << ")" << "\n";
+  old_w -= w;
+  std::cerr << "changed " << old_w.min() << ' ' << old_w.max() << "\n";
 }
 
 struct AggregateStream
@@ -905,7 +1000,7 @@ void analyze(const std::string& output_prefix,
       const KisenAnalyzer::OtherConfig config = 
 	{
 	  search_window, sigmoid_alpha(),
-	  max_progress, position_randomness+osl::random(),
+	  max_progress, (int)(position_randomness+osl::time_seeded_random()),
 	  min_rating, my_eval.get()
 	};
       boost::ptr_vector<boost::thread> threads;
@@ -938,6 +1033,12 @@ void analyze(const std::string& output_prefix,
     now = time(0);
     os << " count " << ctime(&now);
     count_all();
+    {
+      // write progress histogram
+      std::ostringstream ss;
+      ss << output_prefix << eval_type + "-progress-histogram-" << i << ".txt";
+      write_progress_count(ss.str());
+    }
     if (! watch_list.empty()) {
       os << " watch list\n";
       for (size_t i=0; i<watch_list.size(); ++i) {
