@@ -1,6 +1,7 @@
 #include "eval/eval.h"
 #include "eval/evalFactory.h"
 #include "eval/progress.h"
+#include "loss.h"
 #include "l1Ball.h"
 #include "analyzer.h"
 #include "pvFile.h"
@@ -12,7 +13,6 @@
 #include "osl/rating/group.h"
 #include "osl/record/kisen.h"
 #include "osl/state/numEffectState.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/move_generator/legalMoves.h"
 #include "osl/misc/milliSeconds.h"
 #include "osl/eval/ml/openMidEndingEval.h"
@@ -51,7 +51,7 @@ double lambda;
 size_t min_rating = 1500;
 double search_window, search_window_for_validation;
 std::vector<std::string> kisen_filenames;
-double scaling_factor, eta_increment, sigmoid_asymmetry;
+double scaling_factor, eta_increment;
 size_t num_cpus;
 bool smd, fix_step_size;
 size_t mini_batch_size;
@@ -129,9 +129,6 @@ int main(int argc, char **argv)
     ("loss-function,l",
      po::value<std::string>(&loss_function)->default_value(std::string("log")),
      "loss function (log, hinge, exp, sigmoid)")
-    ("sigmoid-asymmetry",
-     po::value<double>(&sigmoid_asymmetry)->default_value(1.0),
-     "asymmetry (only effective when the loss function is sigmoid)")
     ("eta-increment",
      po::value<double>(&eta_increment)->default_value(1.2),
      "scale to modify eta")
@@ -188,7 +185,6 @@ int main(int argc, char **argv)
 }
 
 const int MaxThreads = 64;
-static int cross_validation_randomness = 1;
 
 valarray_t gradient[MaxThreads], Hv[MaxThreads], v_for_Hv;
 stat::Average errors[MaxThreads];
@@ -306,9 +302,9 @@ void MakeGradient::operator()() const
 	double loss = 0;
 	if (loss_function == "sigmoid") {
 	  if (make_hv)
-	    loss = SigmoidLoss::addGradient(w, instance, gradient[thread_id], v_for_Hv, Hv[thread_id], sigmoid_asymmetry);
+	    loss = SigmoidLoss::addGradient(w, instance, gradient[thread_id], v_for_Hv, Hv[thread_id]);
 	  else
-	    loss = SigmoidLoss::addGradient(w, instance, gradient[thread_id], sigmoid_asymmetry);
+	    loss = SigmoidLoss::addGradient(w, instance, gradient[thread_id]);
 	}
 	else if (loss_function == "hinge") {
 	  if (make_hv)
@@ -331,7 +327,7 @@ void MakeGradient::operator()() const
 	}
 	errors[thread_id].add(loss);
       }
-      ApplyMoveOfTurn::doMove(state, best_move);
+      state.makeMove(best_move);
       env.update(state, best_move);
     }
   }
@@ -517,7 +513,7 @@ struct Validation
       env.make(state);
       progress::Effect5x3 progress(state);
       for (size_t j=0; j+1<moves.size(); ++j) {
-	if (state.inCheck(alt(state.getTurn())))
+	if (state.inCheck(alt(state.turn())))
 	  break;			// illegal
 	const Move best_move = moves[j];
 
@@ -525,7 +521,7 @@ struct Validation
 	features->generateRating(state, env, 2000, moves);
 	top_rated[progress.progress16().value()][thread_id].add(! moves.empty() && moves[0].move() == best_move);
 
-	ApplyMoveOfTurn::doMove(state, best_move);
+	state.makeMove(best_move);
 	env.update(state, best_move);
 	progress.update(state, best_move);
       }
