@@ -1,3 +1,4 @@
+#include "moveData.h"
 #include "pvFile.h"
 #include "pvVector.h"
 #include "eval/eval.h"
@@ -122,8 +123,7 @@ int main(int argc, char **argv)
       }
       gpsshogi::PVVector pv;
       bool first = true;
-      vector<std::pair<int, double> > diffs;
-      diffs.reserve(my_eval->maxActive() * 2);
+      gpsshogi::MoveData data;
       while (pr.readPv(pv))
       {
 	osl::NumEffectState current_state(state);
@@ -131,26 +131,24 @@ int main(int argc, char **argv)
 	{
 	  current_state.makeMove(pv[j]);
 	}
-	double value;
-	my_eval->features(state, value, diffs);
+	my_eval->features(state, data);
 
 	if (first)
 	{
-	  for (size_t j = 0; j < diffs.size(); ++j)
+	  for (size_t j = 0; j < data.diffs.size(); ++j)
 	  {
-	    ++positive_position_count[diffs[j].first];
+	    ++positive_position_count[data.diffs[j].first];
 	  }
 	  first = false;
 	}
 	else
 	{
-	  for (size_t j = 0; j < diffs.size(); ++j)
+	  for (size_t j = 0; j < data.diffs.size(); ++j)
 	  {
-	    ++negative_position_count[diffs[j].first];
+	    ++negative_position_count[data.diffs[j].first];
 	  }
 	}
 	pv.clear();
-	diffs.clear();
       }
     }
   }
