@@ -1,5 +1,6 @@
 /* progressevalstat.cc
  */
+#include "moveData.h"
 #include "osl/eval/progressEval.h"
 #include "eval/progressEval.h"
 #include "osl/record/kisen.h"
@@ -23,12 +24,12 @@ int main(int argc, char **argv) {
     osl::NumEffectState state(kisen_file.getInitialState());
     osl::vector<osl::Move> moves = kisen_file.getMoves(i);
 
+    gpsshogi::MoveData data;
     BOOST_FOREACH(osl::Move move, moves) {
-      double value;
-      osl::vector<std::pair<int, double> > out;
-      eval.features(state, value, out, 0);      
-      std::cerr << value << ' ' << value-out.back().second
-		<< ' ' << abs(out.back().second) << "\n";
+      data.clear();
+      eval.features(state, data, 0);      
+      std::cerr << data.value << ' ' << data.value-data.diffs.back().second
+		<< ' ' << abs(data.diffs.back().second) << "\n";
       state.makeMove(move);
     }
   }
