@@ -52,13 +52,7 @@ Analyzer::analyzeLeaf(const NumEffectState& state_org,
   std::cerr << state;
   std::cerr << value << "\n";
 #endif  
-  data.clear();
-  double value;
-  data.diffs.reserve(eval.maxActive()*2);
-  eval.features(state, value, data.diffs);
-  data.value = (int)value;
-  osl::PieceEval pe(state);
-  data.piece_value = pe.value();
+  eval.features(state, data);
 #ifdef DEBUG_ALL
   std::cerr << "\n";
 #endif
