@@ -3,6 +3,7 @@
 #ifndef GPSSHOGI_LEARN_ANALYZER_H
 #define GPSSHOGI_LEARN_ANALYZER_H
 
+#include "moveData.h"
 #include "instanceData.h"
 #include "loss.h"
 #include "pvVector.h"
@@ -14,22 +15,9 @@
 #include <cmath>
 
 namespace gpsshogi
-{
-  using namespace osl;
+{  
+  using osl::NumEffectState;
   
-  struct MoveData
-  {
-    int value, piece_value;
-    sparse_vector_t diffs;
-    explicit MoveData() : value(0), piece_value(0)
-    {
-    }
-    void clear()
-    {
-      diffs.clear();
-    }
-  };
-  std::ostream& operator<<(std::ostream& os, const MoveData& md);
   class Eval;
   class Quiesce;
   struct SigmoidUtil
@@ -65,7 +53,7 @@ namespace gpsshogi
     static void
     makeInstanceSorted(double turn_coef, 
 		       const sparse_vector_t& selected, const sparse_vector_t& sibling,
-		       const vector<size_t>& frequency, int min_frequency, InstanceData& out);
+		       const osl::vector<size_t>& frequency, int min_frequency, InstanceData& out);
   };
 }
 
