@@ -90,6 +90,17 @@ gpsshogi::Eval::findFeature(size_t /*index*/) const
   return boost::make_tuple("not_imlemented", 0, 0);
 }
 
+void gpsshogi::Eval::features(const NumEffectState& state, MoveData& out) const
+{
+  out.clear();
+  out.reserve(maxActive()*2);
+  features(state, out, 0);
+}
+
+void gpsshogi::Eval::featuresProgress(const NumEffectState&, MoveData&) const
+{
+}
+
 /* ------------------------------------------------------------------------- */
 
 gpsshogi::
@@ -188,18 +199,19 @@ PieceEval::setWeight(const double* w)
 }
 
 void gpsshogi::
-PieceEval::features(const NumEffectState& state, double& value,
-		    vector<std::pair<int, double> >& diffs, int offset) const
+PieceEval::features(const NumEffectState& state, 
+		    MoveData& out, int offset) const
 {
   // assert(diffs.size() == 0); // XXX: fix PieceEvalComponent in progress.cc
-  value = 0.0;
+  double value = 0.0;
   for (size_t i=0; i<dimension(); ++i) {
     const double d = differential(state, i);
     if (d) {
-      diffs.push_back(std::make_pair((int)i+offset, d));
+      out.diffs.push_back(std::make_pair((int)i+offset, d));
       value += this->flatValue(i)*d;
     }
   }
+  out.value = value;
 }
 
 double gpsshogi::
@@ -578,22 +590,24 @@ RichEval::saveWeight(double *w) const
 }
 
 void gpsshogi::
-RichEval::features(const NumEffectState& state, double& value,
-		   vector<std::pair<int, double> >& out, int offset) const
+RichEval::features(const NumEffectState& state, MoveData& out, int offset) const
 {
+  double value = 0;
   if (fix_piece) {
     value = piece.eval(state);
-    out.push_back(std::make_pair(0, value));
+    out.diffs.push_back(std::make_pair(0, value));
   } else {
-    piece.features(state, value, out, offset);
+    piece.features(state, out, offset);
+    value = out.value;
   }
   int dim = fix_piece ? 1 : piece.dimension();
   for (size_t i=0; i<others.size(); ++i) {
     double his_value = 0.0;
-    others[i].features(state, his_value, out, offset+dim);
+    others[i].features(state, his_value, out.diffs, offset+dim);
     value += his_value;
     dim += others[i].dimension();
   }
+  out.value = value;
 }
 
 void gpsshogi::
