@@ -3,6 +3,7 @@
 #ifndef GPSSHOGI_LEARN_EVAL_H
 #define GPSSHOGI_LEARN_EVAL_H
 
+#include "moveData.h"
 #include "eval/indexCache.h"
 #include "osl/state/numEffectState.h"
 #include "osl/eval/ml/weights.h"
@@ -67,14 +68,12 @@ namespace gpsshogi
     virtual size_t maxActive() const;
 
     virtual EvalValueStack *newStack(const NumEffectState& state)=0;
-    virtual void features(const NumEffectState&, double& value,
-			  vector<std::pair<int, double> >&, int offset) const=0;
-    void features(const NumEffectState& state, double& value,
-		  vector<std::pair<int, double> >& out) const
-    {
-      features(state, value, out, 0);
-    }
+    virtual void features(const NumEffectState&, MoveData&, int offset) const=0;
+    void features(const NumEffectState& state, MoveData& out) const;
+    /** 進行度に対する偏微分 */
+    virtual void featuresProgress(const NumEffectState&, MoveData&) const;
     virtual int roundUp() const { return 0; }
+    virtual int maxProgress() const { return 1; }
   };
 
   typedef osl::eval::ml::Weights Weights;
@@ -115,8 +114,7 @@ namespace gpsshogi
     }
     int value(Ptype ptype) const { return flatValue(ptype); }
 
-    void features(const NumEffectState&, double& value,
-		  vector<std::pair<int, double> >&, int) const;
+    void features(const NumEffectState&, MoveData&, int) const;
     double differential(const NumEffectState& state, size_t index) const;
     void showSummary(std::ostream&) const;
     size_t lambdaStart() const { return dimension(); };
@@ -402,8 +400,7 @@ namespace gpsshogi
       return dim;
     }
     size_t lambdaStart() const { return fix_piece ? 1 : piece.dimension(); };
-    void features(const NumEffectState&, double& value,
-		  vector<std::pair<int, double> >&, int) const;
+    void features(const NumEffectState&, MoveData&, int) const;
     void showSummary(std::ostream&) const;
     void showAll(std::ostream&) const;
     void setRandom();
