@@ -4,6 +4,7 @@
 #include "eval/progress.h"
 #include "eval/progressFeature.h"
 #include "eval/openMidEnding.h"
+#include "eval/progressEval.h"
 #include "osl/eval/ml/openMidEndingEval.h"
 
 gpsshogi::Eval *
@@ -15,6 +16,12 @@ gpsshogi::EvalFactory::newEval(const std::string &name)
   else if (name == "frich2") {
     return new gpsshogi::RichEval(2, true);
   }
+  else if (name == "progresseval") {
+    return new gpsshogi::KProgressEval();
+  }
+  else if (name == "stableprogresseval") {
+    return new gpsshogi::StableProgressEval();
+  }
 #if (defined LEARN_TEST_PROGRESS)
   else if (name == "handprogress") {
     return new gpsshogi::HandProgressFeatureEval();
@@ -38,5 +45,8 @@ gpsshogi::EvalFactory::newEval(const std::string &name)
   else if (name == "stableopenmidending") {
     return new gpsshogi::StableOpenMidEnding();
   }
+  else if (name == "oslopenmidending") {
+    return new gpsshogi::OslOpenMidEnding();
+  }
   return NULL;
 }
