@@ -1,6 +1,7 @@
 #include "eval/majorPiece.h"
 #include "eval/indexCache.h"
 #include "osl/mobility/rookMobility.h"
+#include "osl/record/csa.h"
 #include <boost/foreach.hpp>
 #include <algorithm>
 
@@ -700,6 +701,14 @@ MajorEffectPieceFeatures<MajorPiece>::featuresOneNonUniq(
   }
 }
 
+template <osl::Ptype MajorPiece>
+const std::string gpsshogi::
+MajorEffectPieceFeatures<MajorPiece>::describe(size_t local_index) const
+{
+  PtypeO ptypeO = static_cast<PtypeO>(local_index+PTYPEO_MIN);
+  return record::csa::show(getOwner(ptypeO))+record::csa::show(getPtype(ptypeO));
+}
+
 template <osl::Ptype MajorPiece>
 void gpsshogi::
 MajorEffectPieceFeatures<MajorPiece>::featuresOneNonUniq(
