@@ -2158,6 +2158,58 @@ SilverAdvance26::featuresOneNonUniq
   }
 }
 
+
+
+void gpsshogi::
+Promotion37::featuresOneNonUniq
+(const NumEffectState &state, IndexCacheI<MaxActiveWithDuplication> &features) const
+{
+  CArray<int,PTYPE_SIZE> count = {{ 0 }};
+  // black
+  for (int x=1; x<=9; ++x) {
+    const Square target(x,3);
+    if (! state[target].isEmpty())
+      continue;
+    int a = state.countEffect(BLACK, target);
+    const int d = state.countEffect(WHITE, target);
+    if (a > 0 && a == d)
+      a += AdditionalEffect::hasEffect(state, target, BLACK);
+    if (a < d)
+      continue;
+    const Ptype ptype = state.findCheapAttack(BLACK, target).ptype();
+    if (isPiece(ptype) && ! isPromoted(ptype))
+      count[ptype]++;
+  }
+  for (int p=PTYPE_BASIC_MIN; p<=PTYPE_MAX; ++p) {
+    if (count[p] > 0)
+      features.add(p, 1);
+    if (count[p] > 1)
+      features.add(p-8, count[p]-1);
+  }
+  // white
+  count.fill(0);
+  for (int x=1; x<=9; ++x) {
+    const Square target(x,7);
+    if (! state[target].isEmpty())
+      continue;
+    int a = state.countEffect(WHITE, target);
+    const int d = state.countEffect(BLACK, target);
+    if (a > 0 && a == d)
+      a += AdditionalEffect::hasEffect(state, target, WHITE);
+    if (a < d)
+      continue;
+    const Ptype ptype = state.findCheapAttack(WHITE, target).ptype();
+    if (isPiece(ptype) && ! isPromoted(ptype))
+      count[ptype]++;
+  }
+  for (int p=PTYPE_BASIC_MIN; p<=PTYPE_MAX; ++p) {
+    if (count[p] > 0)
+      features.add(p, -1);
+    if (count[p] > 1)
+      features.add(p-8, -(count[p]-1));
+  }
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
