@@ -704,6 +704,17 @@ namespace gpsshogi
     (const NumEffectState &state, IndexCacheI<MaxActiveWithDuplication> &features) const;
     const std::string name() const { return "SilverAdvance26"; };
   };
+
+  class Promotion37 : public FeaturesOneNonUniq
+  {
+    enum { DIM = PTYPE_SIZE };
+  public:
+    Promotion37() : FeaturesOneNonUniq(DIM) { }
+    void featuresOneNonUniq
+    (const NumEffectState &state, IndexCacheI<MaxActiveWithDuplication> &features) const;
+    const std::string name() const { return "Promotion37"; };
+    size_t maxActive() const { return DIM*2; };
+  };
 }
 
 #endif /* GPSSSHOGI_SAMPLE_EVAL_LIB_MINORPIECE_H */
