@@ -62,7 +62,7 @@ OpenMidEndingBase::addFinished()
   }
 }
 
-int gpsshogi::OpenMidEndingBase::progressMax() const
+int gpsshogi::OpenMidEndingBase::maxProgress() const
 {
   if (progress_max_16)
     return 16;
@@ -210,7 +210,7 @@ int gpsshogi::
 OpenMidEndingBase::pawnValue() const
 {
 #ifdef EVAL_QUAD
-  const int progress_max = progressMax();
+  const int progress_max = maxProgress();
   const int c0 = progress_max/3, c1 = c0*2, w2 = progress_max - c1;
   int c0_c = c0, w2_c = w2;
   if (! progress_max_16) {
@@ -219,7 +219,7 @@ OpenMidEndingBase::pawnValue() const
   }
   const int scale = c0_c * w2;
 #else
-  const int scale = progressMax();
+  const int scale = maxProgress();
 #endif
   return 128.0 * scale;
 }
@@ -294,7 +294,7 @@ int gpsshogi::
 OpenMidEndingBase::eval(const NumEffectState& state) const
 {
   // TODO: optimize this to use "tri" more effectively.
-  const int progress_max = progressMax();
+  const int progress_max = maxProgress();
   const int progress = this->progress(state);
 #ifdef EVAL_QUAD
   const int c0 = progress_max/3, c1 = c0*2, w2 = progress_max - c1;
@@ -456,11 +456,11 @@ OpenMidEndingBase::saveWeight(double *w) const
 }
 
 void gpsshogi::
-OpenMidEndingBase::features(const NumEffectState& state, double& value,
-			    vector<std::pair<int, double> >& out,
-			    int offset) const
+OpenMidEndingBase::features(const NumEffectState& state, 
+			    MoveData& data, int offset) const
 {
-  const int progress_max = progressMax();
+  osl::vector<std::pair<int,double> >& out = data.diffs;
+  const int progress_max = maxProgress();
   const osl::progress::ml::NewProgress raw_progress(state);
   const int progress = this->progress(raw_progress.progress());
 #ifdef EVAL_QUAD
@@ -470,7 +470,7 @@ OpenMidEndingBase::features(const NumEffectState& state, double& value,
   const int c = progress_max/2;
   const int flat_scale = progress_max;
 #endif
-  value = 0.0;
+  double value = 0.0;
   int dim = 0;
   for (size_t i=0; i<flat.size(); ++i) {
     double his_value = 0.0;
@@ -553,13 +553,15 @@ OpenMidEndingBase::features(const NumEffectState& state, double& value,
     multi_sum += his_value;
     dim += triple[i].dimension();
   }
-  value = compose(value, multi_sum, progress);
   assert(out.size() <= maxActive());
 #ifdef EVAL_QUAD
   if (c0 == w2)
     for (size_t i = 0; i < out.size(); ++i) 
       out[i].second /= c0;
 #endif
+
+  data.value = compose(value, multi_sum, progress);
+  data.progress = progress;
 }
 
 void gpsshogi::
@@ -1075,7 +1077,7 @@ OslOpenMidEnding::~OslOpenMidEnding()
 {
 }
 
-int gpsshogi::OslOpenMidEnding::progressMax() const
+int gpsshogi::OslOpenMidEnding::maxProgress() const
 {
   return progress::ml::NewProgress::maxProgress();
 }
@@ -1143,7 +1145,7 @@ OslOpenMidEnding::newStack(const NumEffectState& state)
 int gpsshogi::
 OslOpenMidEnding::pawnValue() const
 {
-  const int scale = progressMax();
+  const int scale = maxProgress();
   return 128 * scale;
 }
 
@@ -1247,12 +1249,11 @@ OslOpenMidEnding::saveWeight(double *w) const
 }
 
 void gpsshogi::
-OslOpenMidEnding::features(const NumEffectState& state, double& value,
-			   vector<std::pair<int, double> >& out,
+OslOpenMidEnding::features(const NumEffectState& state, MoveData& out,
 			   int offset) const
 {
-  assert(stable_eval->progressMax() == progressMax());
-  stable_eval->features(state, value, out, offset);
+  assert(stable_eval->maxProgress() == maxProgress());
+  stable_eval->features(state, out, offset);
 }
 
 void gpsshogi::
