@@ -25,7 +25,7 @@ namespace gpsshogi
     void addFinished();
     size_t legacyOneDim() const { return legacy_one_dim; }
   public:
-    int progressMax() const;
+    int maxProgress() const;
     int progress(const NumEffectState &state) const;
     int progress(int progress_value) const;
 
@@ -70,8 +70,7 @@ namespace gpsshogi
       return dim;
     }
     size_t lambdaStart() const { return osl::PTYPE_SIZE; };
-    void features(const NumEffectState&, double& value,
-		  vector<std::pair<int, double> >&, int) const;
+    void features(const NumEffectState&, MoveData&, int) const;
     void showSummary(std::ostream&) const;
     void showAll(std::ostream&) const;
     void setRandom();
@@ -94,7 +93,7 @@ namespace gpsshogi
 
     int compose(int flat, MultiInt value, int progress) const
     {
-      return compose(flat, value, progress, progressMax(), progress_max_16);
+      return compose(flat, value, progress, maxProgress(), progress_max_16);
     }
     static int compose(int flat, MultiInt value, int progress, int progress_max,
 		       bool progress_max_16)
@@ -171,7 +170,7 @@ namespace gpsshogi
     OslOpenMidEnding();
     ~OslOpenMidEnding();
 
-    int progressMax() const;
+    int maxProgress() const;
     int progress(const NumEffectState &state) const;
     int progress(int progress_value) const;
 
@@ -186,8 +185,7 @@ namespace gpsshogi
     int flatValue(size_t index) const;
     size_t dimension() const;
     size_t lambdaStart() const { return osl::PTYPE_SIZE; };
-    void features(const NumEffectState&, double& value,
-		  vector<std::pair<int, double> >&, int) const;
+    void features(const NumEffectState&, MoveData&, int) const;
     void showSummary(std::ostream&) const;
     void showAll(std::ostream&) const;
     bool hasPieceValue() const;
