@@ -581,6 +581,22 @@ void gpsshogi::PieceStandCombinationBoth::featuresOneNonUniq(
   }
 }
 
+const std::string gpsshogi::
+PieceStandCombinationBoth::describe(size_t local_index) const
+{
+  int b = local_index >> 7, w = local_index & ((1<<7)-1);
+  std::string ret, pieces="PLKSGBR";
+  for (int i=0; i<7; ++i)
+    if (b & (1<<i))
+      ret += pieces[i];
+  ret += "-";
+  for (int i=0; i<7; ++i)
+    if (w & (1<<i))
+      ret += pieces[i];  
+  return ret;
+}
+
+
 void gpsshogi::PieceStandOnBoard::featuresOneNonUniq(
   const NumEffectState &state,
   IndexCacheI<MaxActiveWithDuplication> &features) const
