@@ -249,6 +249,59 @@ PinPtypePawnAttack::featuresOneNonUniq(
   featuresOneKing<WHITE>(state, features);
 }
 
+
+template <osl::Player Defense>
+void gpsshogi::
+CheckShadowPtype::featuresOneKing(
+  const NumEffectState &state,
+  IndexCacheI<MaxActiveWithDuplication> &features) const
+{
+  const Square king = state.kingSquare<Defense>();
+  const int weight = (Defense == BLACK ? 1 : -1);
+  osl::container::PieceMask open_mask = state.checkShadow(alt(Defense));
+  while (open_mask.any())
+  {
+    const Piece piece = state.pieceOf(open_mask.takeOneBit());
+    if (king.y() == piece.square().y()) // rook h
+    {
+      features.add(piece.ptype() + PTYPE_SIZE * 1, weight);
+    }
+    else if (king.x() == piece.square().x())
+    {
+	if (state.hasEffectByPtypeStrict<LANCE>(alt(Defense),
+						piece.square())) // lance
+      {
+	features.add(piece.ptype() + PTYPE_SIZE * 4, weight);
+      }
+      else // rook v
+      {
+	features.add(piece.ptype() + PTYPE_SIZE * 0, weight);
+      }
+    }
+    else // bishop
+    {
+      if ((Defense == BLACK && piece.square().y() < king.y()) ||
+	  (Defense == WHITE && piece.square().y() > king.y())) // u
+      {
+	features.add(piece.ptype() + PTYPE_SIZE * 2, weight);
+      }
+      else
+      {
+	features.add(piece.ptype() + PTYPE_SIZE * 3, weight);
+      }
+    }
+  }
+}
+void gpsshogi::
+CheckShadowPtype::featuresOneNonUniq(
+  const NumEffectState &state,
+  IndexCacheI<MaxActiveWithDuplication> &features) const
+{
+  featuresOneKing<BLACK>(state, features);
+  featuresOneKing<WHITE>(state, features);
+}
+
+
 namespace gpsshogi
 {
   template class PinBase<2142, PinF>;
