@@ -230,12 +230,11 @@ ProgressFeatureBase::compose(int progress, int progress_max,
     (flat, stage_value, progress, progress_max, false);
 }
 
-void gpsshogi::
-ProgressFeatureBase::features(const NumEffectState& state, double& value,
-			      vector<std::pair<int, double> >& out,
-			      int offset) const
+int gpsshogi::
+ProgressFeatureBase::featuresCommon(const NumEffectState& state, 
+				    MoveData& data, int offset) const
 {
-  ome_eval_t eval(state);
+  osl::vector<std::pair<int,double> >& out = data.diffs;
   int dim = 0, progress = 0;
   for (size_t i=0; i<all.size(); ++i) {
     double his_value = 0.0;
@@ -243,13 +242,35 @@ ProgressFeatureBase::features(const NumEffectState& state, double& value,
     progress += his_value;
     dim += all[i].dimension();
   }
+
   const int progress_max = maxProgress();
-  const int flat_value = eval.progressIndependentValue();
-  const MultiInt stage_value = eval.stageValue();
   if (progress < 0)
     progress = 0;
   if (progress >= progress_max) 
     progress = progress_max-1;
+  return progress;
+}
+
+void gpsshogi::
+ProgressFeatureBase::featuresProgress(const NumEffectState& state, 
+				      MoveData& data) const
+{
+  data.clear();
+  data.reserve(maxActive()*2);
+  data.progress = featuresCommon(state, data, 0);
+  data.value = 0;
+}
+
+void gpsshogi::
+ProgressFeatureBase::features(const NumEffectState& state, 
+			      MoveData& data, int offset) const
+{
+  osl::vector<std::pair<int,double> >& out = data.diffs;
+  const ome_eval_t eval(state);
+  const int progress = featuresCommon(state, data, 0);
+  const int progress_max = maxProgress();
+  const int flat_value = eval.progressIndependentValue();
+  const MultiInt stage_value = eval.stageValue();
 
   const int c0 = progress_max/3, c1 = c0*2;
   if (progress < c0) {
@@ -270,7 +291,8 @@ ProgressFeatureBase::features(const NumEffectState& state, double& value,
     out.push_back(std::make_pair(dimension()-1, (stage_value[2]*3-stage_value[3]*2 +flat_value)/3.0));
   }
 
-  value = compose(progress, progress_max, flat_value, stage_value);
+  data.value = compose(progress, progress_max, flat_value, stage_value);
+  data.progress = progress;
 }
 
 void gpsshogi::
