@@ -45,8 +45,8 @@ namespace gpsshogi
     }
     size_t dimension() const { return dim; }
     size_t lambdaStart() const { return osl::PTYPE_SIZE; };
-    void features(const NumEffectState&, double& value,
-		  vector<std::pair<int, double> >&, int) const;
+    void features(const NumEffectState&, MoveData&, int) const;
+    void featuresProgress(const NumEffectState&, MoveData&) const;
     void showSummary(std::ostream&) const;
     void showAll(std::ostream&) const;
     void setRandom();
@@ -64,6 +64,9 @@ namespace gpsshogi
     static int compose(int progress, int progress_max, int independent, const MultiInt& stage_value);
     const std::string describe(const std::string& feature, size_t local_index) const;
     const std::string describeAll(const std::string& feature) const;
+  private:
+    int featuresCommon(const NumEffectState& state, 
+		       MoveData& data, int offset) const;
   };
   
   class NullProgressFeatureEval : public ProgressFeatureBase
