@@ -26,7 +26,7 @@ L1BallBase::~L1BallBase()
 inline int pick(const gpsshogi::L1Ball::valarray_t& v, const osl::vector<int>& U) 
 {
   // better to use random()?
-  int k[3] = { v[U.front()], v[U[U.size()/2]], v[U.back()] };
+  double k[3] = { v[U.front()], v[U[U.size()/2]], v[U.back()] };
   std::sort(k, k+3);
   if (k[1] == v[U.front()]) return U.front();
   if (k[1] == v[U.back()]) return U.back();
@@ -154,6 +154,7 @@ L1Ball::updateWeight(valarray_t& w, valarray_t& eta, const valarray_t& gradient,
   }
 }
 
+const double perturbation = 1.000;
 void gpsshogi::
 L1Ball::solve(valarray_t& w)
 {
@@ -170,12 +171,15 @@ L1Ball::solve(valarray_t& w)
   prev_sign = 0.0;
   
   int t=0; for (; t<max_iteration; ++t) {
-    iterationHead(t, w, prev_error);
+    iterationHead(t, w, prev_error/perturbation);
     valarray_t gradient;
     double err;
     makeGradient(w, gradient, err);
 #if 0
-    std::cerr << "L1Ball " << t << " " << err << "\n";
+    std::cerr << "L1Ball " << t << " " << err
+	      << ' '<< prev_error
+	      << ' ' << abs(w).sum() 
+	      << " [" << w.min() << ',' << w.max() << "] " <<"\n";
     for (size_t i=0; i<w.size(); ++i)
       std::cerr << " " << w[i];
     std::cerr << "\n";
@@ -183,9 +187,11 @@ L1Ball::solve(valarray_t& w)
       std::cerr << " " << eta[i];
     std::cerr << "\n";
 #endif
-    if (err < tolerance) 
+    if (err < tolerance) {
+      std::cerr << "error < tolerance " << err << ' ' << tolerance << "\n";
       break;
-    if (! std::isnormal(err) || (t && err > prev_error)) {
+    }
+    if (! std::isnormal(err) || (t && err > prev_error*perturbation)) {
       w = best_w;
       ++update_failed;
       reduceEta(eta, update_failed, prev_sign, gradient);
@@ -195,7 +201,7 @@ L1Ball::solve(valarray_t& w)
       continue;
     }
     update_failed = 0;
-    if (t == 0 || err < min_error) {
+    if (t == 0 || err < min_error*perturbation) {
       best_w = w;
       best_w_gradient = gradient;
       min_error = err;
