@@ -7,6 +7,7 @@
 
 #include "osl/record/kisen.h"
 #include "osl/record/csaIOError.h"
+#include "osl/record/csaRecord.h"
 #include "osl/rating/featureSet.h"
 #include "osl/rating/ratingEnv.h"
 #include "osl/search/shouldPromoteCut.h"
@@ -145,7 +146,7 @@ void gpsshogi::KisenAnalyzer::operator()()
       }
       assert(j < moves.size());
       HashKey key(state);
-      key[1] += moves[j].intValue();
+      key.add(moves[j]);
       const bool ignore = (j < 40) && ! visited.insert(key).second;
       if (! ignore
 	  && (! (isCrossValidation() && record.allow_skip_in_cross_validation)
@@ -167,6 +168,24 @@ void gpsshogi::KisenAnalyzer::operator()()
       result->all_errors.push_back(boost::make_tuple
 				   (i, record_errors.getAverage()));    
   }
+
+  if (!isCrossValidation())
+  {
+    for (size_t i = 0; i < record.csa_filenames.size(); ++i)
+    {
+      CsaFile csa(record.csa_filenames[i]);
+      NumEffectState state = csa.getInitialState();
+      const vector<Move> moves = csa.getRecord().getMoves();
+      if (!moves.empty())
+      {
+        Quiesce quiesce(config.my_eval, normal_depth, quiesce_depth);
+        osl::progress::ml::NewProgress progress(state);
+	forEachPosition(-i - 1, 0, 1, quiesce,
+			state, progress.progress16(), moves[0]);
+      }
+    }
+  }
+      
   std::cerr << "#" << std::flush;
 }
 
@@ -189,7 +208,8 @@ KisenAnalyzer::splitFile(const std::string& file, size_t first, size_t last, int
 }
 
 void gpsshogi::
-KisenAnalyzer::splitFileWithMoves(const std::string& file, size_t first, size_t last, int num_assignment, double /*average_records*/, 
+KisenAnalyzer::splitFileWithMoves(const std::string& file, size_t first, size_t last, int num_assignment, double /*average_records*/,
+                                  const std::vector<std::string>& csa_files,
 				  RecordConfig *out, int& written, bool verbose)
 {
   if (num_assignment == 0 || first == last)
@@ -205,6 +225,7 @@ KisenAnalyzer::splitFileWithMoves(const std::string& file, size_t first, size_t
       + moves[i-first];
   const int average_moves = moves.back()/num_assignment;
   size_t cur = first;
+  const int csa_number = csa_files.size() / num_assignment;
   for (int j=0; j<num_assignment; ++j) {
     size_t last_j;
     if (j+1 == num_assignment) 
@@ -226,6 +247,11 @@ KisenAnalyzer::splitFileWithMoves(const std::string& file, size_t first, size_t
 		<< " (" << moves[last_j-first] - moves[cur-first] << ")" << std::endl;
 #endif
     out[written] = RecordConfig(written, cur, last_j, file);
+    const int csa_last_index = (j + 1 == num_assignment) ? csa_files.size() : (csa_number * (j + 1));
+    for (int k = csa_number * j; k < csa_last_index; ++k)
+    {
+      out[written].csa_filenames.push_back(csa_files[k]);
+    }
     ++written;
     cur = last_j;
   }
@@ -233,7 +259,8 @@ KisenAnalyzer::splitFileWithMoves(const std::string& file, size_t first, size_t
 
 void gpsshogi::
 KisenAnalyzer::distributeJob(size_t split, RecordConfig *out, size_t kisen_start, size_t num_records,
-			     const std::vector<std::string>& files, size_t /*min_rating*/)
+			     const std::vector<std::string>& files, size_t /*min_rating*/,
+                             const std::vector<std::string>& csa_files)
 {
   size_t total = 0;
   vector<size_t> totals(files.size()+1), sizes(files.size());
@@ -311,7 +338,8 @@ KisenAnalyzer::distributeJob(size_t split, RecordConfig *out, size_t kisen_start
     if (file_id+1 == end_file) 
       last -= (totals[end_file]-num_records-offset-totals[start_file]);
 #if 1
-    splitFileWithMoves(files[file_id], first, last, assignment[file_id], amount[file_id], out, written,
+    splitFileWithMoves(files[file_id], first, last, assignment[file_id], amount[file_id],
+                       csa_files, out, written,
 		       files.size() > 1);
 #else
     splitFile(files[file_id], first, last, assignment[file_id], amount[file_id], out, written,
