@@ -28,6 +28,7 @@ namespace gpsshogi
       size_t thread_id;
       std::string kisen_filename;
       bool allow_skip_in_cross_validation;
+      std::vector<std::string> csa_filenames;
 
       explicit RecordConfig(size_t thread_id=0, 
 			    size_t first=0, size_t last=0, const std::string& kisen="",
@@ -74,7 +75,8 @@ namespace gpsshogi
      * @param min_rating 0 なら全て使う
      */
     static void distributeJob(size_t n, RecordConfig *out, size_t start, size_t num_records,
-			      const std::vector<std::string>& files, size_t min_rating);
+			      const std::vector<std::string>& files, size_t min_rating,
+                              const std::vector<std::string>& csa_files);
     static void setPriorityRecord(const osl::vector<int>& record) 
     {
       priority_record = record;
@@ -85,7 +87,8 @@ namespace gpsshogi
 			  int num_assignment, double average_records, 
 			  RecordConfig *out, int& written, bool verbose);
     static void splitFileWithMoves(const std::string& file, size_t first, size_t last,
-				   int num_assignment, double average_records, 
+				   int num_assignment, double average_records,
+                                   const std::vector<std::string>& csa_files,
 				   RecordConfig *out, int& written, bool verbose);
     virtual void init();
     virtual void forEachPosition(int record_id, int position_id, size_t position_size,
