@@ -1,3 +1,4 @@
+#include "moveData.h"
 #include "eval/eval.h"
 #include "eval/progress.h"
 #include "eval/progressFeature.h"
@@ -33,7 +34,8 @@ protected:
   }
   int Gold() { return gpsshogi::PieceEval().value(GOLD); }
   int Rook() { return gpsshogi::PieceEval().value(ROOK); }
-  int total(const gpsshogi::Eval& eval, osl::vector<std::pair<int, double> >& diff) 
+  int total(const gpsshogi::Eval& eval,
+	    const osl::vector<std::pair<int, double> >& diff) 
   {
     int sum = 0;
     for (size_t i=0; i<diff.size(); ++i) {
@@ -71,9 +73,10 @@ protected:
 	for (size_t j=0; j<evals.size(); ++j) {
 	  const int value = evals[j].eval(state);
 	
-	  double features_value = -1;
-	  vector<std::pair<int, double> > diffs;
-	  evals[j].features(state, features_value, diffs, 0);
+	  gpsshogi::MoveData data;
+	  const int& features_value = data.value;
+	  const vector<std::pair<int, double> >& diffs = data.diffs;
+	  evals[j].features(state, data, 0);
 #ifndef L1BALL_NO_SORT
           ASSERT_TRUE(__gnu_cxx::is_sorted(diffs.begin(), diffs.end()));
 #endif
@@ -109,6 +112,8 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 
   osl::eval::ml::OpenMidEndingEval::setUp();
   osl::progress::ml::NewProgress::setUp();
+
+  ASSERT_EQ(osl::progress::ml::NewProgress::maxProgress(), eval.maxProgress());
   for (int i=0;i<(isShortTest ? 10 : 200) && (ifs >> file_name) ; i++)
   {
     if (file_name == "")
@@ -130,7 +135,7 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 	eval.debug(state);
       }
       ASSERT_EQ(test_eval.openingValue(), eval.openingValue(state)) << state << m << " progress " << eval.progress(state)
-								    << " progress max " << eval.progressMax();
+								    << " progress max " << eval.maxProgress();
       ASSERT_EQ(test_eval.midgameValue(), eval.midgameValue(state)) << state << m;
 #ifdef EVAL_QUAD
       ASSERT_EQ(test_eval.midgame2Value(), eval.midgame2Value(state)) << state << m;
@@ -145,7 +150,7 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 	stage_value[2] = eval.midgame2Value(state);
 	stage_value[3] = eval.endgameValue(state);
 	int flat = test_eval.progressIndependentValueAdjusted
-	  (eval.progressIndependentValue(state),progress,eval.progressMax());
+	  (eval.progressIndependentValue(state),progress,eval.maxProgress());
 	ASSERT_NEAR(test_eval.value(),
 		    eval.compose(flat, stage_value, progress),
 		    2.0) << state << m;
@@ -209,7 +214,6 @@ TEST_F(EvalTest, testStableOpenMidEndingEval)
 TEST_F(EvalTest, testAllDifferential)
 {
   gpsshogi::PieceEval eval;
-  double value;
   {
     const NumEffectState state(CsaString(
 				 "P1-KY-KE-GI-KI-OU-KI-GI-KE-KY\n"
@@ -223,7 +227,7 @@ TEST_F(EvalTest, testAllDifferential)
 				 "P9+KY+KE+GI * +OU+KI+GI+KE+KY\n"
 				 "+\n").getInitialState());
     gpsshogi::MoveData md;
-    eval.features(state, value, md.diffs, 0);
+    eval.features(state, md, 0);
   }
   {
     const NumEffectState state(CsaString(
@@ -239,7 +243,7 @@ TEST_F(EvalTest, testAllDifferential)
 				 "P+00FU\n"
 				 "-\n").getInitialState());
     gpsshogi::MoveData md;
-    eval.features(state, value, md.diffs, 0);
+    eval.features(state, md, 0);
   }
 }
 
@@ -270,10 +274,9 @@ TEST_F(EvalTest, testConstruct)
     EXPECT_EQ(-Gold()*2, eval.eval(state));
     EXPECT_EQ(-Gold()*2, reval.eval(state));
 
-    double value = -1;
-    vector<std::pair<int, double> > diffs;
-    reval.features(state, value, diffs, 0);
-    EXPECT_EQ(-Gold()*2, static_cast<int>(value));
+    gpsshogi::MoveData data;
+    reval.features(state, data, 0);
+    EXPECT_EQ(-Gold()*2, static_cast<int>(data.value));
   }
 
   {
@@ -530,7 +533,7 @@ TEST_F(EvalTest, testStableProgressEval)
       state.makeMove(m);
       osl_eval.update(state, m);
       ASSERT_EQ(osl_eval.openingValue(), eval.openingValue(state)) << state << m << " progress " << eval.progress(state)
-								    << " progress max " << eval.progressMax();
+								    << " progress max " << eval.maxProgress();
       ASSERT_EQ(osl_eval.endgameValue(), eval.endgameValue(state)) << state << m;
       ASSERT_NEAR(osl_eval.value(), eval.eval(state), 2.0) << state << m;
     }
