@@ -20,8 +20,8 @@ TEST(PvFileTest, testConstruct)
 TEST(PvFileTest, testRW)
 {
   PVVector pv;
-  pv.push_back(Move(Position(7,7),Position(7,6),PAWN,PTYPE_EMPTY,false,BLACK));
-  pv.push_back(Move(Position(3,3),Position(3,4),PAWN,PTYPE_EMPTY,false,WHITE));
+  pv.push_back(Move(Square(7,7),Square(7,6),PAWN,PTYPE_EMPTY,false,BLACK));
+  pv.push_back(Move(Square(3,3),Square(3,4),PAWN,PTYPE_EMPTY,false,WHITE));
   {
     gpsshogi::PVFileWriter pw("pvFile-test.gz");
   }
