@@ -13,9 +13,9 @@ using namespace osl;
 using namespace osl::eval;
 extern bool isShortTest;
 
-const int Gold = gpsshogi::PieceEval().value(GOLD);
-const int Bishop = gpsshogi::PieceEval().value(BISHOP);
-const int Rook = gpsshogi::PieceEval().value(ROOK);
+int Gold() { return gpsshogi::PieceEval().value(GOLD); }
+int Bishop() { return gpsshogi::PieceEval().value(BISHOP); }
+int Rook() { return gpsshogi::PieceEval().value(ROOK); }
 
 TEST(QuiesceTest, testPv)
 {
@@ -73,7 +73,7 @@ TEST(QuiesceTest, testCapture)
     gpsshogi::PVVector pv;
     int value;
     quiesce.quiesce(state, value, pv);
-    EXPECT_EQ(Gold*2, value);
+    EXPECT_EQ(Gold()*2, value);
     const Move m25hi(Square(2,8),Square(2,5),ROOK,GOLD,false,BLACK);
     EXPECT_EQ((size_t)1, pv.size());
     EXPECT_EQ(m25hi, pv[0]);
@@ -112,7 +112,7 @@ TEST(QuiesceTest, testCapture)
     gpsshogi::PVVector pv;
     int value;
     quiesce.quiesce(state, value, pv);
-    EXPECT_EQ(Rook*2, value);
+    EXPECT_EQ(Rook()*2, value);
     EXPECT_EQ((size_t)1, pv.size());
   }
   {
@@ -148,7 +148,7 @@ TEST(QuiesceTest, testCapture)
     gpsshogi::PVVector pv;
     int value;
     quiesce.quiesce(state, value, pv);
-    EXPECT_EQ(Rook*2 - Gold*2, value);
+    EXPECT_EQ(Rook()*2 - Gold()*2, value);
     EXPECT_EQ((size_t)2, pv.size());
   }
 }
@@ -158,7 +158,7 @@ TEST(QuiesceTest, testCheckmate)
   gpsshogi::PieceEval eval;
   gpsshogi::Quiesce quiesce(&eval);
   EXPECT_GT(quiesce.infty(BLACK), quiesce.infty(WHITE));
-  EXPECT_GT(quiesce.infty(BLACK), Rook*4);
+  EXPECT_GT(quiesce.infty(BLACK), Rook()*4);
   {
     NumEffectState state(CsaString(
 			   "P1 *  *  * -OU *  *  *  *  * \n"
@@ -216,7 +216,7 @@ TEST(QuiesceTest, testCheckmate)
     gpsshogi::PVVector pv;
     int value;
     quiesce.quiesce(state, value, pv);
-    EXPECT_LT(value, -Bishop*2);
+    EXPECT_LT(value, -Bishop()*2);
     const Move m88um(Square(2,2),Square(8,8),PBISHOP,BISHOP,true,WHITE);
     EXPECT_EQ((size_t)1, pv.size());
     EXPECT_EQ(m88um, pv[0]);
@@ -225,7 +225,7 @@ TEST(QuiesceTest, testCheckmate)
     pv.clear();
 
     quiesce.quiesce(state, value, pv, -300, 300);
-    EXPECT_LT(value, -Bishop*2);
+    EXPECT_LT(value, -Bishop()*2);
     EXPECT_EQ((size_t)1, pv.size());
     EXPECT_EQ(m88um, pv[0]);
   }
