@@ -27,8 +27,12 @@
 #include "osl/record/kakinoki.h"
 #include "osl/record/myshogi.h"
 #include "osl/record/opening/openingBook.h"
+#include "osl/record/opening/bookInMemory.h"
 #include "osl/game_playing/alphaBetaPlayer.h"
 #include "osl/game_playing/gameState.h"
+#include "osl/search/alphaBeta3.h"
+#include "osl/search/alphaBeta4.h"
+#include "osl/search/searchRecorder.h"
 #include "osl/misc/filePath.h"
 #include "osl/misc/random.h"
 #include "osl/misc/sjis2euc.h"
@@ -42,7 +46,7 @@
 #include "osl/rating/ratingEnv.h"
 #include "osl/move_probability/featureSet.h"
 #include "osl/move_generator/legalMoves.h"
-#include "osl/misc/iconvConvert.h"
+#include "osl/misc/eucToLang.h"
 #include "osl/c/facade.h"
 #include "osl/oslConfig.h"
 
@@ -110,6 +114,7 @@ void setCommandsMain(gpsshell::MySession* s)
   s->addCommand("recorddb",              &gpsshell::MySession::recorddb );
   s->addCommand("search",                &gpsshell::MySession::search );
   s->addCommand("qsearch",               &gpsshell::MySession::qsearch );
+  s->addCommand("search4",               &gpsshell::MySession::search4 );
   s->addCommand("checkmate_attack",      &gpsshell::MySession::checkmate_attack );
   s->addCommand("checkmate_escape",      &gpsshell::MySession::checkmate_escape );
   s->addCommand("threatmate",            &gpsshell::MySession::threatmate );
@@ -138,6 +143,7 @@ void setCommandsMain(gpsshell::MySession* s)
   s->addCommand("onext_random_weight",   &gpsshell::MySession::openingNextRandomWeight );
   s->addCommand("oinclude",              &gpsshell::MySession::openingInclude );
   s->addCommand("oshow_shortest_lines",  &gpsshell::MySession::openingShowShortestLines);
+  s->addCommand("book_in_memory",	 &gpsshell::MySession::showBookInMemory);
   // --- commands rerated with ignore lists
   s->addCommand("set_ignorelists %file", &gpsshell::MySession::setIgnoreList );
   s->addCommand("ignorelist_show",       &gpsshell::MySession::ignoreListShow );
@@ -549,19 +555,19 @@ MySession::recorddb(const std::vector<std::string>& params)
   int win, loss, gps_win, gps_loss, bonanza_win, bonanza_loss;
   gpsshogi::recorddb::query(state, win, loss, gps_win, gps_loss, bonanza_win, bonanza_loss);
   if (win + loss)
-    std::cout << osl::IconvConvert::eucToLang("ץ ")
-	      << win << osl::IconvConvert::eucToLang("")
-	      << loss << osl::IconvConvert::eucToLang(" ")
+    std::cout << osl::misc::eucToLang("ץ ")
+	      << win << osl::misc::eucToLang("")
+	      << loss << osl::misc::eucToLang(" ")
 	      << 100.0*win/(win+loss) << "%" << std::endl;
   if (gps_win + gps_loss)
     std::cout << "GPS v.s. Bonanza "
-	      << gps_win << osl::IconvConvert::eucToLang("")
-	      << gps_loss << osl::IconvConvert::eucToLang(" ")
+	      << gps_win << osl::misc::eucToLang("")
+	      << gps_loss << osl::misc::eucToLang(" ")
 	      << 100.0*gps_win/(gps_win+gps_loss) << "%" << std::endl;
   if (bonanza_win + bonanza_loss)
     std::cout << "Bonanza v.s. GPS "
-	      << bonanza_win << osl::IconvConvert::eucToLang("")
-	      << bonanza_loss << osl::IconvConvert::eucToLang(" ")
+	      << bonanza_win << osl::misc::eucToLang("")
+	      << bonanza_loss << osl::misc::eucToLang(" ")
 	      << 100.0*bonanza_win/(bonanza_win+bonanza_loss) << "%" << std::endl;
 #endif
 }
@@ -595,6 +601,40 @@ MySession::search(const std::vector<std::string>& params)
   std::cout << move << std::endl;
 }
 
+void gpsshell::
+MySession::search4(const std::vector<std::string>& params)
+{
+  static const size_t time_default = 30;
+  static size_t time = time_default;
+  if (params.size() >= 2) 
+  {
+    try 
+    {
+      time = boost::lexical_cast<size_t>(params[1]);
+    } 
+    catch (boost::bad_lexical_cast& blc) 
+    {
+      std::cerr << blc.what() << std::endl;
+      std::cerr << "USAGE: search <time_in_sec>" << std::endl
+                << "time is now " << time << " "
+                << "(default: " << time_default << ")"
+                << std::endl;
+      return;
+    }
+  }
+
+  osl::search::SearchState2::checkmate_t solver;
+  osl::search::CountRecorder recorder;
+  osl::SimpleHashTable table;
+  table.setVerbose(true);    
+  osl::NumEffectState state(board->getState());
+  osl::search4::AlphaBeta4 search(state,solver,&table,recorder);
+  osl::search::TimeAssigned assign(osl::MilliSeconds::Interval(time*1000),
+				   osl::MilliSeconds::Interval(time*1000));
+  osl::Move best_move = search.computeBestMoveIteratively(2000,100,0,0,assign);
+  std::cout << best_move << std::endl;
+}
+
 void show(const osl::search::QuiescenceRecord& qrecord)
 {
   std::cerr << "best move " << osl::record::csa::show(qrecord.bestMove()) << "\n";
@@ -858,14 +898,21 @@ MySession::rating(const std::vector<std::string>& params)
 void gpsshell::
 MySession::rating2(const std::vector<std::string>& params)
 {
+  const osl::NumEffectState state = board->getState();
   static int min_rate = -200;
+  osl::Move single_move;
   if (params.size() > 1) {
-    std::istringstream is(params[1]);
-    is >> min_rate;
+    std::string option_string = params[1];
+    try {
+      single_move = osl::record::csa::strToMove(option_string, state);
+    }
+    catch (...) {
+      std::istringstream is(option_string);
+      is >> min_rate;
+    }
   }
   static const osl::move_probability::StandardFeatureSet&
     fs = osl::move_probability::StandardFeatureSet::instance();
-  const osl::NumEffectState state = board->getState();
   osl::MoveStack history;
   if (board->getCurrentMove().isNormal())
     history.push(board->getCurrentMove());
@@ -877,6 +924,10 @@ MySession::rating2(const std::vector<std::string>& params)
     std::cout << "note: threatmate "
 	      << osl::record::csa::show(info.threatmate_move) 
 	      << "\n";
+  if (single_move.isNormal()) {
+    double p = fs.matchExp(info, single_move);
+    std::cout << p << ' ' << log(p) << '\n';
+  }
   osl::MoveLogProbVector moves;
   fs.generateLogProb2(info, moves);
   for (size_t i=0; i<moves.size(); ++i) {
@@ -1445,6 +1496,18 @@ MySession::ignoreListShowAll(const std::vector<std::string>& params)
   }
 }
 
+void gpsshell::
+MySession::showBookInMemory(const std::vector<std::string>& params)
+{
+  const osl::BookInMemory& book = osl::BookInMemory::instance();
+  osl::HashKey key(board->getState());
+  osl::MoveVector moves;
+  book.find(key, moves);
+  BOOST_FOREACH(osl::Move move, moves)
+    std::cout << osl::record::csa::show(move) << std::endl;
+  std::cout << "BookInMemory has " << moves.size() << std::endl;  
+}
+
 #ifdef OSL_SMP
 void gpsshell::
 MySession::setNumCPUs(const std::vector<std::string>& params)
