@@ -95,6 +95,7 @@ namespace gpsshell
     void recorddb(const std::vector<std::string>& params);
     void search(const std::vector<std::string>& params);
     void qsearch(const std::vector<std::string>& params);
+    void search4(const std::vector<std::string>& params);
     void checkmate_attack(const std::vector<std::string>& params);
     void checkmate_escape(const std::vector<std::string>& params);
     void threatmate(const std::vector<std::string>& params);
@@ -137,6 +138,8 @@ namespace gpsshell
      * command: oshow_shortest_lines [top_n]
      */
     void openingShowShortestLines(const std::vector<std::string>& params);
+    /** show contents in osl::record::opening::BookInMemory */
+    void showBookInMemory(const std::vector<std::string>& params);
 
     void setIgnoreList(const std::vector<std::string>& params);
     void ignoreListShow(const std::vector<std::string>& params);
