@@ -24,7 +24,6 @@
             [twitter_clj.twitter :as twitter]
             [clojure.string :as str]
             [clojure.contrib.command-line :as cmd]
-            [clojure.contrib.duck-streams :as duck]
             [clojure.contrib.logging :as log]))
 
 ;; ==================================================
@@ -36,16 +35,55 @@
 ;; Functions
 ;; ==================================================
 
-(defn parse-line
-  "Parse lines that gpsusi produces."
-  [line]
-  (let [r1 #"^info depth (\d+) .* score cp (-?\d+) .* pv (.*)$"]
-    (if-let [m (re-find r1 line)]
-      (let [[_ depth cp pv] m
-            first-move (first (str/split pv #" "))]
-        {:depth (Integer. depth) :cp (Integer. cp) :pv pv :first-move first-move})
-      nil)))
+(defmacro parse-integer
+  [key-str ret xs]
+  `(let [symbl# (keyword ~key-str)
+         ret# ~ret
+         xs#  ~xs]
+     (recur (merge ret# {symbl# (Integer/parseInt (second xs#))}) (rest (rest xs#)))))
 
+(defn- append-first-move
+  "For a map col with :pv, return a new map with :first-move"
+  [col]
+  (assert (:pv col))
+  (letfn [(get-first-move [pv]
+            (first (str/split pv #"\s")))]
+    (let [pv (:pv col)]
+      (assoc col :first-move (get-first-move pv)))))
+
+(defn- parse-info-depth-message
+  "Parse the info depth message and return a corresponding map"
+  [msg]
+  (loop [ret {}
+         xs  (str/split msg #"\s")]
+    (if-not (seq xs)
+      ret
+      (condp = (first xs)
+        "info"     (recur ret (rest xs))
+        "depth"    (parse-integer "depth"    ret xs)
+        "seldepth" (parse-integer "seldepth" ret xs)
+        "score"    (recur ret (rest xs))
+        "cp"       (parse-integer "cp"       ret xs)
+        "nodes"    (parse-integer "nodes"    ret xs)
+        "nps"      (parse-integer "nps"      ret xs)
+        "time"     (parse-integer "time"     ret xs)
+        "pv"       (recur (merge ret {:pv (str/join " " (rest xs))})
+                          nil)
+        (log/error (str "Unknown attributes for InfoDepthMessage: " xs))))))
+
+(defn parse-line
+  "Parse a raw line that gpsusi produces."
+  [message]
+  (try
+    (condp (comp seq re-seq) message
+      #"^info depth (\d+)$" nil
+      #"^info depth (\d+) " (-> message
+                                parse-info-depth-message
+                                append-first-move)
+      nil)
+    (catch Exception e
+      (log/error (str "Failed to parse message: " message))
+      nil)))
 
 (defn start-monitor
   "Start a monitor thread reading what gpsusi produces."
@@ -57,7 +95,7 @@
       (if-let [line (first lines)]
         (condp (comp seq re-seq) line
           #"warning stop ignored" (common/sort-pv @common/pv) ; base
-          #"bestmove (.*)"        :>> #(if (empty @common/pv) ; base
+          #"bestmove (.*)"        :>> #(if (empty? @common/pv) ; base
                                          (reset! common/pv [{:cp 0 :pv (-> % first (nth 1))}])
                                          (common/sort-pv @common/pv))
           (if-let [m (parse-line line)]                       ; else
@@ -65,6 +103,7 @@
                   depth (:depth m)]
               (if (< current-depth depth)
                 (do
+                  (log/debug (format "PV deepened: %s" m))
                   (reset! common/pv [m])
                   (recur (rest lines)))
                 (do
@@ -104,7 +143,7 @@
   (cmd/with-command-line args
     "lein trampoline run [--dry-run]"
     [[dry-run?      "Do not tweet" false]
-     [force-think   "Think at least n seconds for each move" 0]
+     [force-think   "Think at least n seconds for each move" 20]
      [force-update? "Update possile exisiting tweets" false]
      [gpsusi        "Path to gpsusi" "../../gpsshogi/bin/gpsusi"]
      remains]
@@ -112,7 +151,7 @@
     (swap! common/options assoc :force-think (Integer. force-think))
     (swap! common/options assoc :force-update force-update?)
     (swap! common/options assoc :gpsusi gpsusi)
-    (let [gpsusi-cmd (str (:gpsusi @common/options) " --extended-usi 1") ;; extended mode
+    (let [gpsusi-cmd (str (:gpsusi @common/options) " --extended-usi 1 -N 7") ;; extended mode
           [proc stdin stdout stderr] (engine/start-engine gpsusi-cmd)]   ;; search engine
       (ki2/start-ki2-engine (:gpsusi @common/options)) ;; normal mode
       (twitter/post-version (:id-name @common/options))
@@ -128,7 +167,7 @@
             (log/info (format ">>> [%d] %s" nmove line))
             (when (and snapshot-thread
                        (pos? (:force-think @common/options)))
-              (log/debug "wait for test")
+              (log/debug (format "Force to think for %d secs..." (:force-think @common/options)))
               (Thread/sleep (* 1000 (:force-think @common/options))))
             (when snapshot-thread
               (interrupt-thread snapshot-thread))
