@@ -292,7 +292,7 @@ ProcessBoard::generate(const std::string& line,
   if (image) {
     assert(!file_name.empty());
     const bf::path file_path = dir / file_name;
-    image->write(file_path.file_string());
+    image->write(file_path.string());
   } else
     return "";
   return file_name;
