@@ -27,7 +27,7 @@ DisproofPieces::attack(const CheckMoveList& moves, const SimpleState& state,
       result = result.max(p->record->disproofPieces());
     }
   }
-  ProofPiecesUtil::addMonopolizedPieces(state, alt(state.getTurn()), max, 
+  ProofPiecesUtil::addMonopolizedPieces(state, alt(state.turn()), max, 
 					result);
   return result;
 }
