@@ -18,7 +18,7 @@ ProofPieces::defense(const CheckMoveList& moves, const NumEffectState& state,
     assert(p->record);
     result = result.max(p->record->proofPieces());
   }
-  const Player defender = state.getTurn();
+  const Player defender = state.turn();
   if (! effect_util::UnblockableCheck::isMember(defender, state))
     ProofPiecesUtil::addMonopolizedPieces(state, alt(defender), max,
 					  result);
