@@ -125,7 +125,7 @@ void OracleDisproverTest::testAdjustMove()
     "-\n").getInitialState();
   HashEffectState state(sstate);
   const PathEncoding path(WHITE);
-  const Move last_move = Move(Position(3,4), Position(2,2),
+  const Move last_move = Move(Square(3,4), Square(2,2),
 				PKNIGHT, PTYPE_EMPTY, true, BLACK);
   DualCheckmateSearcher<> checker(limit);
   checker.setVerbose(!isShortTest);
@@ -159,8 +159,8 @@ void OracleDisproverTest::testAdjustMove()
     disprover.proofEscape(state2, state2.getHash(),
 			  path, oracle, escape_move, last_move);
   CPPUNIT_ASSERT_EQUAL(true, result);
-  CPPUNIT_ASSERT_EQUAL(Position(2,1), escape_move.from());
-  CPPUNIT_ASSERT_EQUAL(Position(2,2), escape_move.to());
+  CPPUNIT_ASSERT_EQUAL(Square(2,1), escape_move.from());
+  CPPUNIT_ASSERT_EQUAL(Square(2,2), escape_move.to());
   CPPUNIT_ASSERT_EQUAL(GOLD, escape_move.capturePtype());
 }
 
@@ -270,7 +270,7 @@ void OracleDisproverTest::testCheck()
     "-\n").getInitialState();
   HashEffectState state(sstate);
   const PathEncoding path(WHITE);
-  const Move last_move = Move(Position(3,4), Position(2,2),
+  const Move last_move = Move(Square(3,4), Square(2,2),
 				PKNIGHT, PTYPE_EMPTY, true, BLACK);
   DualCheckmateSearcher<> checker(limit);
   checker.setVerbose(!isShortTest);
@@ -321,7 +321,7 @@ void OracleDisproverTest::testNoCheck()
     "-\n").getInitialState();
   HashEffectState state(sstate);
   const PathEncoding path(WHITE);
-  const Move last_move = Move(Position(3,4), Position(2,2),
+  const Move last_move = Move(Square(3,4), Square(2,2),
 				PKNIGHT, PTYPE_EMPTY, true, BLACK);
   DualCheckmateSearcher<> checker(limit);
   checker.setVerbose(!isShortTest);
@@ -353,8 +353,8 @@ void OracleDisproverTest::testNoCheck()
     disprover.proofEscape(state2, state2.getHash(),
 			  path, oracle, escape_move, last_move);
   CPPUNIT_ASSERT(result);
-  CPPUNIT_ASSERT_EQUAL(escape_move.from(), Position(2,1));
-  CPPUNIT_ASSERT_EQUAL(escape_move.to(), Position(2,2));
+  CPPUNIT_ASSERT_EQUAL(escape_move.from(), Square(2,1));
+  CPPUNIT_ASSERT_EQUAL(escape_move.to(), Square(2,2));
 }
 
 static bool isNoCheckmate(const char *org, const char *similar)
@@ -364,9 +364,9 @@ static bool isNoCheckmate(const char *org, const char *similar)
   const size_t limit = 100000;
   DualCheckmateSearcher<> checker(limit);
   checker.setVerbose(!isShortTest);
-  CheckHashTable& table = checker.getTable(state.getTurn());
+  CheckHashTable& table = checker.getTable(state.turn());
   Move check_move;
-  const PathEncoding path(state.getTurn());
+  const PathEncoding path(state.turn());
   AttackOracleAges oracle_age;
   const bool win = checker.isWinningState(limit, state, state.getHash(), path, check_move,
 					  oracle_age);
@@ -381,8 +381,8 @@ static bool isNoCheckmate(const char *org, const char *similar)
   HashEffectState state2(CsaString(similar).getInitialState());
   OracleDisprover<CheckHashTable> disprover(table);
 
-  PathEncoding path2(alt(state2.getTurn()));
-  path2.pushMove(Move(Position(5,5),PAWN,alt(state2.getTurn())));
+  PathEncoding path2(alt(state2.turn()));
+  path2.pushMove(Move(Square(5,5),PAWN,alt(state2.turn())));
   CPPUNIT_ASSERT(path != path2);
   
   const bool result = disprover.proofNoCheckmate(state2, path2, record, path);
@@ -692,7 +692,7 @@ void OracleDisproverTest::testPawnCheckmateLose()
     "-\n").getInitialState();
   HashEffectState state(sstate);
   const PathEncoding path(WHITE);
-  const Move last_move = Move(Position(3,4), PKNIGHT, BLACK);
+  const Move last_move = Move(Square(3,4), PKNIGHT, BLACK);
   DualCheckmateSearcher<> checker(limit);
   checker.setVerbose(!isShortTest);
   CheckHashTable& table = checker.getTable(BLACK);
