@@ -492,6 +492,7 @@ my $config = { usi_engine    => '',
 	       usinewgame    => 1,
 	       resign_value  => 0,
 	       logdir        => "log",
+	       startup_usi   => '',
 	       server_stdio  => ""
 	     };
 GetOptions($config, 'usi_engine=s', 'csa_host=s', 'csa_port=i',
@@ -499,6 +500,7 @@ GetOptions($config, 'usi_engine=s', 'csa_host=s', 'csa_port=i',
 	   'time_response=f', 'ponder!', 'verbose!', 'send_pv!',
 	   'stop_interval=f', 'pawn_value=f',
 	   'stable_ratio=f', 'usinewgame!', 'resign_value=i', 'logdir=s',
+	   'startup_usi=s',
 	   'server_stdio=s') || die "$!";
 
 die "usi_engine not specified" unless $config->{usi_engine};
@@ -580,6 +582,8 @@ sub init_client ($) {
       if ($line =~ /^option name UsiOutputPawnValue type spin default ([0-9]+)/);
     last if ($line =~ /^readyok/);
   }
+  write_line($client, $config->{startup_usi})
+    if ($config->{startup_usi});
   $status->{client} = $client;
 }
 
@@ -722,14 +726,18 @@ sub assign_time ($) {
   }
   my $p = $config->{ponder} ? 2.2 : 2.0;
   my $t = ($nmoves < 104) ? ((125 - $nmoves)/$p+1) : $nmoves/8;
-  my $a = 0.85*($left - 60) / $t + 1;
+  my $reduce = ($config->{sec_limit_up} < 30) ? 0.85 : 1.0;
+  my $a = $reduce*($left - 60) / $t + 1;
+  my $scale = ($config->{sec_limit_up} < 30) ? 2.5 : 5;
   $status->{sec_standard} = $a;
-  $status->{sec_hard} = $a*2.5 < ($left-60) ? $a*2.5 : ($left-60);
+  $status->{sec_hard} = $a*$scale < ($left-60) ? $a*$scale : ($left-60);
 
   # adjustment
   ## limit
-  my $maximum = 24.0 * $config->{sec_limit} / 1500;
-  $a = $maximum if ($a > $maximum);
+  if ($config->{sec_limit_up} < 30) {
+    my $maximum = 24.0 * $config->{sec_limit} / 1500;
+    $a = $maximum if ($a > $maximum);
+  }
   ## increase
   if ($status->{board}->{turn} eq $status->{my_color}
       && $left > $config->{sec_limit}/2
@@ -830,9 +838,13 @@ sub valid_usi ($) {
   my ($line) = @_;
   if ($line =~ /^info /) {
     $line =~ s/\s+score cp\s+-?[0-9]+(\s|$)/ /g;
+    $line =~ s/\s+score mate\s+-?[0-9]+(\s|$)/ /g;
     $line =~ s/\s+time\s+[0-9]+(\s|$)/ /g;
     $line =~ s/\s+seldepth\s+[0-9]+(\s|$)/ /g;
     $line =~ s/\s+depth\s+[0-9]+(\s|$)/ /g;
+    $line =~ s/\s+upperbound/ /g;
+    $line =~ s/\s+lowerbound/ /g;
+    $line =~ s/\s+multipv\s+-?[0-9.]+(\s|$)/ /g;
     $line =~ s/\s+nodes\s+-?[0-9]+(\s|$)/ /g;
     $line =~ s/\s+nps\s+-?[0-9.]+(\s|$)/ /g;
     $line =~ s/\s+hashfull\s+[0-9]+(\s|$)/ /g;
@@ -954,6 +966,10 @@ sub handle_client_message ($$) {
     die "unknown syntax $line" unless (valid_usi($line));
     my $depth = ($line =~ /\s+depth\s+([0-9]+)/) && $1;
     my $score = ($line =~ /\s+score cp\s+(-?[0-9.]+)/) && $1;
+    if($line =~ /\s+score mate\s+(-?[0.9].+)/){
+      if($1 > 0){ $score = 30000-$1; }
+      else { $score = -30000-$1; }
+    }
     my $nodes = ($line =~ /\s+nodes\s+([0-9.]+)/) && $1;
     my ($usimove,@pv) = ($line =~ /\s+pv\s+(.+)/) && split(/\s+/, $1);
     return if (!$usimove || $usimove =~ /resign/); # ignore resign unless final decision
@@ -990,6 +1006,7 @@ sub handle_client_message ($$) {
   }
   elsif ($line =~ /^bestmove\s+(.+)/) {
     my $move = $1;
+    $move =~ s/\s+ponder\s+.*//;
     die "unknown syntax $line" unless (valid_usi_move($move));
     $status->{bestmove} = $status->{id};
     my $csa = $status->{board}->usi2csa($move);
