@@ -216,7 +216,7 @@ void analyze(const NumEffectState& src, const vector<Move>& moves, size_t move_n
       max_pv_length = std::min((size_t)10, max_pv_length);
     for (size_t i=0; i<max_pv_length; ++i) {
       if (is_threatmate(s, table)) {
-	ret << "(" << record::K_TSUMERO << ")";
+	ret << "(" K_TSUMERO ")";
 	ret_en << " (threatmate) ";
       }
       ret << record::ki2::show(move.moves[i], s, i ? move.moves[i-1] : move.move);
@@ -267,7 +267,7 @@ void analyze(const NumEffectState& src, const vector<Move>& moves, size_t move_n
 	s.makeMove(move);      
 	for (size_t j=1; j<std::min((size_t)4, others[i].second.size()); ++j) {
 	  if (is_threatmate(s, table)) {
-	    ret << "(" << record::K_TSUMERO << ")";
+	    ret << "(" K_TSUMERO ")";
 	    ret_en << " (threatmate) ";
 	  }
 	  const Move move = others[i].second[j];
