@@ -10,6 +10,7 @@
 #include "osl/record/psn.h"
 #include "osl/record/kanjiCode.h"
 #include <boost/lexical_cast.hpp>
+#include <sstream>
 
 void explain(const osl::NumEffectState& state, const osl::annotate::AnalysesResult& shared,
 	     std::string& japanese_euc, std::string& english)
@@ -17,6 +18,20 @@ void explain(const osl::NumEffectState& state, const osl::annotate::AnalysesResu
   using namespace osl;
   using namespace osl::record;
   using namespace osl::annotate;
+  // repetition
+  if (! shared.repetition.empty()) 
+  {
+    japanese_euc += "Ʊ (";
+    english += "Repetition of position (";
+    for (size_t i=0; i<shared.repetition.size(); ++i) {
+      std::ostringstream ss;
+      ss << (i?",":"") << shared.repetition[i];
+      japanese_euc += ss.str();
+      english += ss.str();
+    }
+    japanese_euc += "). ";
+    english += "). ";
+  }
   // checkmate
   if (shared.checkmate == True) 
   {
