@@ -1,11 +1,7 @@
 #ifndef _BOARD_AND_LIST_TABCHILD_H
 #define _BOARD_AND_LIST_TABCHILD_H
 #include "boardTabChild.h"
-#if QT_VERSION >= 0x040000
 #define QListViewItem Q3ListViewItem
-#else
-#define Q3ListViewItem QListViewItem
-#endif
 
 class MoveTree;
 class Q3ListViewItem;
@@ -23,11 +19,7 @@ public:
   osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move> &moves);
   void toLastState();
 private slots:
-#if QT_VERSION >= 0x040000
   void updateBoardSlot(Q3ListViewItem *item);
-#else
-  void updateBoardSlot(QListViewItem *item);
-#endif
 
 protected:
   virtual void updateBoard(Q3ListViewItem *item);
