@@ -8,7 +8,7 @@
 #include <QPushButton>
 #include <QLineEdit>
 #include <QRegExp>
-#include <iostream>
+#include <QRadioButton>
 
 BoardEditor2::BoardEditor2(QWidget *parent)
   : TabChild(parent), state(), player(osl::BLACK)
@@ -25,6 +25,10 @@ BoardEditor2::BoardEditor2(QWidget *parent)
   QPushButton *to_white_stand_button = new QPushButton("To &White Stand", this);
   vlayout->addWidget(to_black_stand_button);
   vlayout->addWidget(to_white_stand_button);
+  QRadioButton *black_turn = new QRadioButton(tr("Black Turn"), this);
+  QRadioButton *white_turn = new QRadioButton(tr("White Turn"), this);
+  vlayout->addWidget(black_turn);
+  vlayout->addWidget(white_turn);
   hlayout->addLayout(vlayout);
   setLayout(hlayout);
 
@@ -36,6 +40,10 @@ BoardEditor2::BoardEditor2(QWidget *parent)
 	  this, SLOT(reserveToBlack()));
   connect(to_white_stand_button, SIGNAL(clicked()),
 	  this, SLOT(reserveToWhite()));
+  connect(black_turn, SIGNAL(toggled(bool)),
+          this, SLOT(blackTurn(bool)));
+  connect(white_turn, SIGNAL(toggled(bool)),
+          this, SLOT(whiteTurn(bool)));
 }
 
 const osl::NumEffectState& BoardEditor2::getState()
@@ -85,3 +93,23 @@ void BoardEditor2::reserveToWhite()
 {
   board->reserveToStand(osl::WHITE);
 }
+
+void BoardEditor2::blackTurn(bool checked)
+{
+  if (checked)
+  {
+    board->setTurn(osl::BLACK);
+  }
+}
+
+void BoardEditor2::whiteTurn(bool checked)
+{
+  if (checked)
+  {
+    board->setTurn(osl::WHITE);
+  }
+}
+// ;;; Local Variables:
+// ;;; mode:c++
+// ;;; c-basic-offset:2
+// ;;; End:
