@@ -217,32 +217,6 @@ void CheckMoveItem::paintCell(QPainter *p, const QColorGroup &cg,
     MoveTreeItem::paintCell(p, cg, column, width, align);
 }
 
-
-#if QT_VERSION < 0x040000
-class MoveCountTip : public QToolTip
-{
-public:
-  MoveCountTip(QWidget *parent, Q3ListView *w) : QToolTip(parent), listView(w) {
-  }
-protected:
-  virtual void maybeTip(const QPoint &pos);
-private:
-  Q3ListView *listView;
-};
-
-void MoveCountTip::maybeTip(const QPoint &pos)
-{
-  CheckMoveItem *item = (CheckMoveItem *)listView->itemAt(pos);
-  if (item)
-  {
-    QRect r = listView->itemRect(item);
-    QString s;
-    s.sprintf("%d %s", item->getNumMoves(), "手");
-    tip(r, s);
-  }
-}
-#endif
-
 CheckMoveViewer::CheckMoveViewer(QWidget *parent, const char *name)
   : MoveTree(parent, name)
 {
@@ -254,16 +228,10 @@ CheckMoveViewer::CheckMoveViewer(QWidget *parent, const char *name)
     setColumnAlignment(1, Qt::AlignRight);
     setColumnAlignment(2, Qt::AlignRight);
   }
-#if QT_VERSION < 0x040000
-  tip = new MoveCountTip(viewport(), this);
-#endif
 }
 
 CheckMoveViewer::~CheckMoveViewer()
 {
-#if QT_VERSION < 0x040000
-  delete tip;
-#endif
 }
 
 bool CheckMoveViewer::analyze(const osl::state::NumEffectState &sstate,
