@@ -45,9 +45,6 @@ private:
   boost::scoped_ptr<searcher_t> searcher;
   osl::state::NumEffectState initial_state;
   const osl::checkmate::DfpnTable *table; // acquaintance
-#if QT_VERSION <= 0x040000
-  MoveCountTip *tip;
-#endif
 };
 
 class CheckmateViewer : public BoardAndListTabChild
