@@ -1,13 +1,7 @@
 #include "copyLabel.h"
 
 #include <qclipboard.h>
-#if QT_VERSION >= 0x040000
-#include <Q3PopupMenu>
-#include <QContextMenuEvent>
-#else
-#include <qpopupmenu.h>
-#define Q3PopupMenu QPopupMenu
-#endif
+#include <QtGui>
 #include <qapplication.h>
 #include <cmath>
 
@@ -16,11 +10,12 @@ void CopyLabel::contextMenuEvent(QContextMenuEvent *e)
   if (text() == "")
     return;
 
-  Q3PopupMenu* contextMenu = new Q3PopupMenu(this);
-  contextMenu->insertItem("&Copy", this,
-			  SLOT(copy()));
-  contextMenu->exec(e->globalPos());
-  delete contextMenu;
+  QMenu menu(this);
+  QAction *copyAction = new QAction("&Copy", this);
+  connect(copyAction, SIGNAL(activated()),
+          this, SLOT(copy()));
+  menu.addAction(copyAction);
+  menu.exec(e->globalPos());
 }
 
 void CopyLabel::copy()
