@@ -9,11 +9,13 @@
 #include "gpsshogi/gui/util.h"
 
 #include "osl/search/searchMonitor.h"
+#include "osl/eval/ml/openMidEndingEval.h"
 #include "osl/record/csaRecord.h"
 #include "osl/record/csaString.h"
 #include "osl/record/csaIOError.h"
 #include "osl/record/kisen.h"
 #include "osl/record/ki2.h"
+#include "osl/record/usi.h"
 
 #include <qlayout.h>
 #include <QListWidget>
@@ -31,6 +33,7 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 
+#include <boost/foreach.hpp>
 #include <iostream>
 
 volatile bool KifuViewer::analyzeOnlineEnabled = false;
@@ -196,6 +199,8 @@ void KifuViewer::boardMoved(osl::Move move)
     manualMoves.push_back(move);
     manualIndex = manualMoves.size() - 1;
   }
+
+  doAutoSaveMoves();
 }
 
 void KifuViewer::updateTime()
@@ -282,7 +287,7 @@ void KifuViewer::reloadFile()
   if (! watchFileEnabled)
     return;
   QMutexLocker lk(&kifuFileMutex);
-  if (kifuFile->reloadIfChanged())
+  if (kifuFile && kifuFile->reloadIfChanged())
   {
     open(kifuFile.get());
     toLastState();
@@ -660,6 +665,8 @@ void KifuViewer::clearState()
 {
   comments.clear();
   move_info.clear();
+  move_eval.clear();
+  move_progress.clear();
   players->clear();
   list->clear();
   manualMoves.clear();
@@ -686,6 +693,8 @@ void KifuViewer::openEvalGraph(bool force)
   {
     DualEvaluationDialog *eval = new DualEvaluationDialog(this);
     eval->setInfo(move_info);
+    eval->setRawValues(move_eval, move_progress);
+
     connect(this, SIGNAL(indexUpdate(int)), eval, SLOT(setIndex(int)));
     connect(eval, SIGNAL(selected(int)), this, SLOT(updateIndex(int)));
     connect(this, SIGNAL(stateReset()), eval, SLOT(accept()));
@@ -712,17 +721,33 @@ void KifuViewer::open(KifuFile *file)
                       file->getPlayerName(osl::BLACK), players);
   new QListWidgetItem(QString::fromUtf8("後手: ") +
                       file->getPlayerName(osl::WHITE), players);
+  if (file->getYear() > 0)
+    new QListWidgetItem(QString::fromUtf8("対局日: ")
+			+ QString("%1").arg(file->getYear())
+			+ QString::fromUtf8("年"), players);
   for (size_t i = 0; i < file->getInitialComment().size(); ++i) {
     new QListWidgetItem(file->getInitialComment()[i], players);
   }
   comments = file->getComments();
   move_info = file->getSearchInfo();
+  {
+    osl::NumEffectState state(initialState);
+    osl::eval::ml::OpenMidEndingEval eval(state);
+    const double scale = 200.0
+      / eval.captureValue(osl::newPtypeO(osl::WHITE,osl::PAWN));
+    BOOST_FOREACH(osl::Move move, file->getMoves()) {
+      state.makeMove(move);
+      eval.update(state, move);
+      move_eval.push_back(eval.value()*scale);
+      move_progress.push_back(1.0*eval.progressValue()/eval.progressMax());
+    }
+  }
   if (file != kifuFile.get())
   {
     kifuFile.reset(file);
   }
-  openEvalGraph(false);
   emit stateReset();
+  openEvalGraph(false);
 }
 
 void KifuViewer::open(const osl::state::SimpleState& state,
@@ -820,6 +845,40 @@ const KifuFile *KifuViewer::getKifuFile()
   return kifuFile.get();
 }
 
+void KifuViewer::setAutoSaveFile(const QString& filename)
+{
+  if (filename.endsWith(".usi"))
+  {
+    autoSaveFile.reset(new QFile(filename));
+  }
+  else
+  {
+    autoSaveFile.reset(NULL);
+  }
+}
+
+void KifuViewer::doAutoSaveMoves()
+{
+  if (!autoSaveFile)
+    return;
+
+  osl::stl::vector<osl::Move> moves;
+  getStateAndMovesToCurrent(moves);
+
+  if (autoSaveFile->fileName().endsWith(".usi"))
+  {
+    autoSaveFile->open(QIODevice::WriteOnly | QIODevice::Append);
+    autoSaveFile->write("position startpos moves ");
+    QStringList slist;
+    for (size_t i=0; i<moves.size(); ++i)
+    {
+      slist << (osl::record::usi::show(moves[i]).c_str());
+    }
+    autoSaveFile->write(slist.join(" "));
+    autoSaveFile->write("\n");
+    autoSaveFile->close();
+  }
+}
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
