@@ -7,6 +7,7 @@
 #include "kifuFile.h"
 #include <boost/scoped_ptr.hpp>
 #include <boost/thread/mutex.hpp>
+#include <QFile>
 #include <QMutex>
 
 class MoveList;
@@ -44,6 +45,7 @@ public:
   QWidget *moveGenerateDialog();
   static void setAnalyzeOnline(bool enable);
   void analyze();
+  void setAutoSaveFile(const QString& filename);
 public slots:
   void updateIndex(int i);
   void openEvalGraph(bool force);
@@ -69,6 +71,7 @@ private:
   void updateState();
   void resetState();
   void clearState();
+  void doAutoSaveMoves();
 
   MoveList *list;
   QTableWidget *timeView;
@@ -80,11 +83,14 @@ private:
   int index;
   osl::stl::vector<osl::Move> manualMoves;
   int manualIndex;
-  osl::stl::vector<QString> comments;
-  osl::stl::vector<osl::record::SearchInfo> move_info;
+  osl::vector<QString> comments;
+  osl::vector<osl::record::SearchInfo> move_info;
+  osl::vector<int> move_eval;
+  osl::vector<double> move_progress;
   QString filename;
   boost::scoped_ptr<KifuFile> kifuFile;
   QMutex kifuFileMutex;
+  boost::scoped_ptr<QFile> autoSaveFile;
   bool ignoreMoveSignal;
   static volatile bool analyzeOnlineEnabled, stateForAnalysisChanged;
   volatile bool watchFileEnabled;
