@@ -1,17 +1,11 @@
 #ifndef _MOVELIST_H
 #define _MOVELIST_H
 #include <qglobal.h>
-#if QT_VERSION >= 0x040000
-#include <Q3ListBox>
-#else
-#include <qlistbox.h>
-#define Q3ListBox QListBox
-#define Q3ListBoxText QListBoxText
-#endif
+#include <QListWidget>
 #include "osl/state/simpleState.h"
 #include "osl/stl/vector.h"
 
-class MoveList : public Q3ListBox
+class MoveList : public QListWidget
 {
 Q_OBJECT
 public:
