@@ -3,12 +3,7 @@
 #include "osl/eval/pieceEval.h"
 
 #include <QtGui>
-#if QT_VERSION >= 0x040000
 #include <Q3Header>
-#else
-#define Q3ListViewItemIterator QListViewItemIterator
-#include <qheader.h>
-#endif
 
 MoveTree::~MoveTree()
 {
