@@ -2,13 +2,7 @@
 #define _MOVE_TREE_H
 #include "osl/move.h"
 #include <qglobal.h>
-#if QT_VERSION >= 0x040000
 #include <Q3ListView>
-#else
-#include <qlistview.h>
-#define Q3ListView QListView
-#define Q3ListViewItem QListViewItem
-#endif
 
 class MoveTreeItem;
 class QMenu;
