@@ -16,7 +16,7 @@ public:
   void backward();
   void toLastState();
   int moveCount() const;
-  osl::state::SimpleState getStateAndMovesToCurrent(osl::stl::vector<osl::Move>&);
+  osl::NumEffectState getStateAndMovesToCurrent(osl::stl::vector<osl::Move>&);
   MoveList *moveList;
 
 signals:
