@@ -598,6 +598,14 @@ void Viewer::saveMovesToCurrent()
   }
 }
 
+void Viewer::autoSaveMoves()
+{
+  const QString fileName = 
+    QFileDialog::getSaveFileName(this,
+                                 tr("Auto Save file"), "", tr("Usi (*.usi)"));
+  kifuViewer->setAutoSaveFile(fileName);
+}
+
 void Viewer::exportCurrent()
 {
   QString s = getFilenameToSave();
@@ -759,6 +767,10 @@ void Viewer::highlightBookMove(bool on)
 {
   ((TabChild *)currentPage())->highlightBookMove(on);
 }
+void Viewer::showArrowMove(bool on)
+{
+  ((TabChild *)currentPage())->showArrowMove(on);
+}
 
 void Viewer::notifyEffect(QWidget *widget)
 {
