@@ -86,6 +86,7 @@ public slots:
   void moveGenerateDialog();
   void toggleOrientation();
   void saveMovesToCurrent();
+  void autoSaveMoves();
   void exportCurrent();
   void copy();
   void copyBoardAndMoves();
@@ -96,6 +97,7 @@ public slots:
   void enableEffect(bool on);
   void highlightLastMove(bool on);
   void highlightBookMove(bool on);
+  void showArrowMove(bool on);
   void setAnalyzeOnline(bool enable);
   void kifuAnalyze();
   void openEvalGraph();
